# 商品词
data = ['女装', '男装', '服饰配件', '皮带', '帽子', '围巾', '内衣裤袜', '女鞋', '男鞋', '箱包', '运动服', '休闲服装',
        '运动鞋', '运动包', '户外包', '配件', '运动', '瑜伽', '球迷用品', '户外', '登山', '野营', '旅行用品', '自行车',
        '骑行装备', '零配件', '电动车', '交通工具', '钟表类', '打火机', '瑞士军刀', '眼镜', '时尚饰品', '翡翠',
        '和田玉', '琥珀蜜蜡', '其他玉石', '陶瓷', '紫砂', '建盏', '茶周边', '特色手工艺', '木作', '书画', '钱币',
        '收藏', '珠宝', '文玩', '收藏品', '黄金', '彩宝', '钻石', '珍珠', '珍品拍卖', '美容护肤', '彩妆', '香水',
        '美妆工具', '美容', '个护仪器', '美容美体医疗器械', '洗护清洁剂', '卫生巾', '香薰', '个人护理', '隐形眼镜',
        '护理液', '计生用品', '粮油米面', '南北干货', '调味品', '零食', '坚果', '特产', '咖啡', '麦片', '冲饮', '酒类',
        '保健食品', '膳食营养补充食品', '传统滋补营养品', '食品卡券', 'OTC非处方药', '鲜花速递', '花卉仿真', '绿植园艺',
        '畜牧', '养殖物资', '农机', '农具', '农膜', '农用物资', '童装', '婴儿装', '亲子装', '童鞋', '婴儿鞋', '亲子鞋',
        '孕妇装', '孕产妇用品', '营养', '婴童用品', '奶粉', '辅食', '营养品', '婴童尿裤', '宠物', '宠物食品及用品',
        '玩具', '童车', '积木', '模型', '动漫', '周边', '桌游', '乐器', '吉他', '钢琴', '书籍', '杂志', '报纸',
        '学习用品', '教育音像', '数字阅读', '节庆用品', '文创', '手机', '智能设备', '笔记本电脑', 'DIY电脑', '品牌台机',
        '品牌一体机', '服务器', '平板电脑', '电脑硬件', '显示器', '电脑周边', '摄影', '摄像', '大家电', '3C数码配件',
        '影音电器', '网络设备', '网络相关', '数码存储设备', '电子教育', '办公用品', '办公设备', '耗材', '相关服务',
        '电子元器件市场', '电玩', '居家布艺', '床上用品', '厨房', '烹饪用具', '餐饮具', '家居饰品', '个人保健',
        '护理电器', '厨房电器', '生活电器', '居家日用', '家庭', '个人清洁工具', '收纳整理', '住宅家具', '商业',
        '办公家具', '全屋定制', '装修设计', '施工', '基础建材', '家装主材', '家装灯饰光源', '金属材料及制品', '清洗',
        '食品', '商业设备', '机械设备', '汽车用品', '汽车零配件', '摩托车', '电工', '五金', '工具', '保健', '护理',
        '理疗器械', '医疗保健', '全屋智能', '二手百货', '二手3C数码', '二手奢侈品', '二手潮品鞋服', '电信充值中心',
        '手机号码', '增值业务', '生活娱乐充值', '网络游戏点卡', '游戏服务', '保险', '兑换卡', '线下消费卡', '教育培训',
        '购物提货券', '演出', '赛事', '房产', '医疗及健康服务', '汽车售后服务', '新车', '二手车', '蕾丝衫', '雪纺衫',
        '派克服', 'POLO衫', '休闲运动套装', '套装', '学生校服', '工作制服', '医护制服', '其它制服', '职业女裤套装',
        '职业女裙套装', '酒店工作制服', '时尚套装', '衬衫', '短裤', '中老年女装', '连体衣', '毛针织衫', '汉服', '唐装',
        '民族服装', '舞台服装', '舞台装', '毛呢外套', '羽绒服', '羊绒衫', '毛衣', '羊毛衫', '半身裙', '皮衣', '抹胸',
        '设计师', '潮牌女装', '马夹', '打底裤', '裤子', '西装裤', '正装裤', '休闲裤', '牛仔裤', '棉裤', '羽绒裤',
        '西装', '背心吊带', '礼服', '晚装', '婚纱', '旗袍', 'T恤', '卫衣', '绒衫', '风衣', '皮草', '棉衣', '棉服',
        '大码连衣裙', '大码女装', '大码牛仔裤', '大码衬衫', '连衣裙', '短外套', '中老年男装', '西裤', '西服',
        '西服套装', '西服上装', '针织衫', '皮裤', '工装制服', '大码男装', '卫裤', '毛呢大衣', '背心', '马甲', '夹克',
        '潮牌男装', '中山装', '三件套', '手套', '帽子套件', '二件套', '多件套', '新娘头饰', '婚纱礼服配件', '皇冠配饰',
        '婚纱手套', '头纱', '婚纱裙撑', '耳套', '腰带', '腰链', '口袋巾', '丝巾', '披肩', '领结', '领部配件', '假领',
        '领带', '领针', '手帕', '袖扣', '领带夹', '防晒护具', '防晒裤', '防晒服', '防晒手套', '防晒口罩', '防晒帽',
        '防晒披肩', '防晒袖套', '吊袜带', '塑身美体裤', '塑身衣', '塑身连体衣', '塑身分体套装', '塑身腰封', '腰夹',
        '塑身上衣', '女士内衣', '文胸', '文胸套装', '男士内裤', '内裤', '女士内裤', '吊带', '保暖裤', '保暖内衣',
        '保暖上装', '保暖背心', '保暖套装', '睡衣上装', '睡衣', '睡裤', '家居裤', '家居服套装', '睡袍', '浴袍', '睡裙',
        '连体袜', '袜子', '美腿袜', '短袜', '打底袜', '丝袜', '长筒袜', '乳贴', '内衣配件', '肩带', '插片', '胸垫',
        '搭扣', '肚兜', '少女文胸', '帆布鞋', '棉拖', '拖鞋', '一字拖', '包头拖', '人字拖', '时尚休闲沙滩鞋', '凉鞋',
        '时装凉鞋', '洞洞鞋', '一字带凉鞋', '罗马凉鞋', '高帮鞋', '女鞋配件', '雨鞋', '布鞋', '低帮鞋', '牛津鞋',
        '时尚休闲鞋', '松糕', '摇摇鞋', '休闲板鞋', '穆勒鞋', '单鞋', '乐福鞋', '豆豆鞋', '马丁靴', '靴子', '时装靴',
        '时尚雪地靴', '弹力靴', '袜靴', '短靴', '切尔西靴', '坡跟鞋', '高跟鞋', '方根高跟鞋', '细跟高跟鞋', '网面鞋',
        '沙滩鞋', '皮鞋', '休闲皮鞋', '男鞋配件', '工装鞋', '卡套', '单肩', '斜挎包', '男士包袋', '男士钱包',
        '男士双肩包', '男士钥匙包', '证件包', '商务公文包', '手机包', '男士手包', '卡包', '名片夹', '钥匙包',
        '女士包袋', '零钱包', '单肩包', '手拿包', '双肩包', '化妆包', '钱包', '手提包', '箱包相关配件', '拉杆包',
        '功能箱包', '电脑包', '妈咪包', '休闲运动包', '腰包', '胸包', '旅行袋', '旅行配件', '旅行包', '旅行箱',
        '专业相机包', '登山包', '书包', '运动毛衣', '线衫', '运动背心', '运动内衣', '运动文胸', '运动内衣套装',
        '运动内裤', '羽绒马甲', '运动马甲', '棉马甲', '单马甲', '运动T恤', '运动卫衣', '套头衫', '运动棉衣',
        '运动羽绒服', '运动半身裙', '运动裙', '运动连衣裙', '运动POLO衫', '健身套装', '健身服装', '训练防护衣裤',
        '健身衣', '健身裤', '高尔夫球服', '运动球服', '其它球服', '棒球服', '橄榄球服', '运动茄克', '外套',
        '运动中长裤／短裤', '运动裤', '运动长裤', '运动牛仔裤', '运动风衣', '运动套装', '跑步套装', '跑步服', '跑步外套',
        '跑步T恤', '跑步裤', '乒乓球鞋', '老爹鞋', '排球鞋', '棒球鞋', '网球鞋', '综合训练鞋', '室内健身鞋',
        '运动沙滩鞋', '羽毛球鞋', '跑步鞋', '青少年鞋', '健步鞋', '篮球鞋', '运动拖鞋', '其它运动鞋', '板鞋', '休闲鞋',
        '足球鞋', '防雨罩', '背包配件', '运动水壶', '鞋袋', '收纳配件包', '杂物袋', '脏衣篓', '鞋带', '保健环',
        '运动首饰', '智能手环', '挎包', '拎包', '休闲包', '旅行箱包', '围脖', '相机包', '防水箱包', '手机袋', '防水箱',
        '雨衣', '雨裤', '雨披', '运动袜', '户外摄影包', '贴章', '魔术贴章', '运动帽', '腿套', '手包', '运动护具',
        '钱包卡套', '鞋垫', '雪套', '套脚', '双肩背包', '运动鼓包', '头巾', '遮耳', '单肩背包', '鞋油', '电竞卫衣',
        '电子竞技', '电竞帽', '电竞T恤', '电竞夹克', '击剑护具', '击剑运动', '击剑鞋', '击剑袜', '击剑剑包', '保龄球',
        '保龄球挂件', '保龄球鞋', '保龄球瓶', '保龄球包', '赛车鞋', '赛车', '赛车球迷用品', '赛车帽', '赛车服',
        '更多慢跑装备', '慢跑', '有氧运动', '座椅', '游乐场', '体育场馆设施', '场馆音响设备', '草地铺设及设备',
        '显示设备', '场馆灯光设备', '游乐场设施', '塑胶', '运动地板', '泳池设备', '乒乓球拍套', '乒乓球', '乒乓底板',
        '乒乓套胶', '海绵', '单胶片', '计分器', '翻分牌', '乒乓球袜', '乒乓球台', '乒乓球网架', '乒乓球捡球器',
        '乒乓球挡板', '粘合剂', '胶水', '乒乓球发球机', '乒乓球服', '乒乓球成品拍', '乒乓球盒', '乒乓球训练器',
        '负重设备', '跆拳道', '武术', '搏击', 'T型棍', 'T型拐', '九节鞭', '双截棍', '三节甩棍', '伸缩棍',
        '健美操>健美操鞋', '健美操', '体操', '台球三角架', '台球', '台球修杆器', '皮头', '杆头', '球杆保养工具',
        '台球杆', '台球三指手套', '皮头胶水', '杆盒', '杆筒', '杆袋', '巧克粉', '球杆保养油', '台尼', '台球布',
        '台球桌', '球杆加长器', '台球挂件', '台球架杆器', '巧粉夹', '巧粉袋', '中国象棋', '麻将', '棋牌', '益智类',
        '扑克', '牌九', '筹码', '魔方', '3D魔方', '官捉兵', '富饶之城', '筹码架', '洗牌机', '转盘', '拉密',
        '以色列麻将', '大富翁', '斗兽棋', 'UNO牌', '飞行棋', '矮人矿工', '国际象棋', '围棋', '德国心脏病', '发牌机',
        '多米诺骨牌', '军棋', '陆战棋', '万智牌', '色子', '骰子', '跳棋', '筛盅', '卡卡颂', '裁判服', '教练用品',
        '计分牌', '计时工具', '裁判专用哨', '换人牌', '运动紧急用品', '棒球', '棒球球迷用品', '棒球帽', '棒球棒',
        '棒球手套', '高尔夫练习网', '高尔夫', '高尔夫球钉', '高尔夫球杆', '高尔夫手套', '高尔夫鞋', '推杆练习器',
        '高尔夫伞', '高尔夫服装', '高尔夫球帽', '高尔夫球', '高尔夫杆套', '沙滩裤', '游泳', '女士泳衣', '戏水玩具',
        '救生衣', '连体泳衣', '游泳拖鞋', '分体泳衣', '亲子家庭装', '比基尼', '情侣装泳衣', '男士泳衣', '游泳池',
        '游泳专用包', '游泳圈', '裹裙', '披纱', '多用球桌', '飞镖', '桌上足球', '室内休闲', '桌上冰球', '悠悠',
        '溜溜球', '其它运动用品', '充气设备', '排球', '排球服', '排球球网', '排球战术板', '排球柱', '普拉提背部训练器',
        '瑜伽发带', '眼枕', '瑜伽圈', '普拉提圈', '瑜伽舒展器', '健康架', '瑜伽手套', '伸展带', '瑜伽绳', '健身球架',
        '瑜伽铺巾', '瑜伽垫捆绑带', '毛扣', '冥想垫', '瑜伽环', '瑜伽砖', '瑜伽鞋', '瘦小腿套', '瑜伽香薰精油',
        '瑜伽椅', '瑜伽包', '瑜伽工艺品', '瑜伽服用胸垫', '瑜伽垫', '瑜伽袜子', '瑜伽体位图靠垫', '瘦手臂套',
        '空中瑜伽吊床', '瑜伽披肩', '瑜伽球', '倒立凳', '瑜伽清理鼻腔用具', '瑜伽拉力带', '网球', '网球包', '避震器',
        '网球拍', '网球赛事纪念', '网球帽', '网球线', '网球服', '手胶', '吸汗带', '冰球', '速滑', '冰上运动', '冰球杆',
        '滑冰服', '冰刀鞋', '马车配件', '马术运动', '马匹保健', '马匹清洁', '马房用品', '马术文化用品', '马术场地用具',
        '橄榄球头盔', '橄榄球', '橄榄球鞋', '壁球鞋', '壁球', '壁球拍', '壁球拍线', '射箭', '箭靶', '更多篮球用品',
        '篮球', '篮球板', '篮球服', '篮球充气设备', '篮球架', '篮球框', '篮球袜', '篮球网', '投篮机', '投篮训练器',
        '篮球球迷用品', '篮球包', '篮球袋', '足球袜', '足球', '守门员手套', '足球战术板', '足球球门', '足球鞋钉',
        '足球服', '训练背心(分组对抗)', '足球球网', '赛事纪念品', '运动类活动', '甩脂机', '律动机', '跑步机',
        '大型健身器械', '骑马机', '登山机', '力量训练器械(综合性)', '健身车', '举重床', '卧推器', '器械减震垫',
        '大型健身器械配件区', '划船机', '力量训练器械(局部型)', '倒立机', '力量训练器械(综合型)', '跳跳床', '蹦蹦床',
        '普拉提床', '动感单车', '健身路径', '冲浪机', '椭圆机', '走步机', '漫步机', '活力板', '轮滑', '滑板',
        '极限运动', '极限飞盘', '双排轮', '摆摆乐', '弹跳跷', '更多极限运动', '风火轮', '竞技独轮车', '滑板车',
        '暴走鞋', '便携魔轮', '直排轮', '漂移版', '分体滑板', '运动毛巾', '羽毛球', '羽毛球训练器', '羽毛球拍',
        '羽毛球网', '网柱', '网架', '羽毛球包', '羽毛球拍线', '羽毛球发球机', '羽毛球服', '跨栏架', '田径运动器材',
        '起跑器', '跳高架', '跳高杆', '海绵垫', '体操垫', '铅球', '铁饼架', '接力棒', '铅球架', '链球', '起跑器架',
        '铁饼', '山羊', '跳马', '跳箱', '田径运动鞋', '田径运动服', '更多民间运动用品', '毽子', '空竹', '民间运动',
        '沙包', '可乐球', '滚铁环', '无极健身球', '板羽球拍', '剑球', '技巧球', '拔河绳', '陀螺', '嗒嗒球', '球拍',
        '藤球', '板羽球', '三毛球', '运动用品', '跳舞毯', '跳跳环', '闪光跳', '踏步机', '中小型健身器材', '杠铃',
        '脸部肌肉训练器', '美臀训练器', '扭腰盘', '俯卧撑架', '健身椅', '健身球', '保健球', '美腿机', '腿部训练器',
        '筋膜刀', '筋膜柱', '计步器', '健身锤', '按摩捶', '筋膜球', '足底按摩垫', '腕力器', '腕力球', '臂力器',
        '拉力绳', '拉力器', '健腹轮', '健腹器', '吊环', '肩颈辅助训练器械', '哑铃', '美腰机', '挺腰器', '健身器材套装',
        '负重装备', '握力器', '筋膜枪', '计时器', '跳跳球', '蹦蹦球', 'ems微电流穿戴健身仪', '单双杠', '引体向上',
        '娃娃跳', '弹跳器', '跳绳', '壶铃', '仰卧板', '健腹板', '体重秤', '健康秤', '健身踏板', '韵律踏板', '呼啦圈',
        '弹力棒', '健身棒', '中小型健身器材配件区', '小腿拉伸训练器', '拉筋训练器', '辅配件', '防潮垫', '地席', '枕头',
        '地布', '钓台', '垂钓装备', '探鱼器', '钓鱼伞', '垂钓小配件', '钓鱼椅、凳', '鱼网', '虾笼', '其它渔具', '鱼护',
        '钓鱼报警器', '铅皮', '止血钳', '钓鱼船推进器', '路亚钳', '抄网杆', '绑钩器', '鱼线', '线盒', '钓鱼服',
        '钓鱼手套', '渔具包', '鱼钩', '钓箱', '控鱼钳', '浮漂', '钓鱼剪刀', '抄网头', '太空豆', '线组', '钓竿', '鱼饵',
        '漂盒', '铅坠', '伸缩扣', '钓鱼帽', '饵料盒', '竿止', '失手绳', '脱钩器', '钓鱼船', '钓鱼鞋', '支架', '醒目豆',
        '渔具套装', '抄网', '鱼线轮', '打窝船', '浮漂座', '冲浪', '滑水', '帆板', '滑水手套', '冲浪板', '滑水板套',
        '防滑垫', '滑水板', '蜡块', '防寒衣', '防磨衣', '冲浪板背袋', '滑水鞋', '鼻头', '滑水绳', '脚绳', '睡袋',
        '户外眼镜', '望远镜', '夜视仪', '红外夜视仪', '数码望远镜', '天文望远镜', '望远镜配件', '激光测距望远镜',
        '普通望远镜', '垂钓望远镜', '冰镐', '登山攀岩攀冰', '镁粉袋', '保护器', '攀岩鞋', '冰爪', '绳索', '挂片',
        '岩石塞', '头盔', '冰锥', '扁带', '滑轮', '下降器', '抱石垫', '锁具', '岩钉', '上升器', '攀岩绳包', '膨胀钉',
        '快挂(专业攀岩用)', '安全带', '防晒衣', '户外服装', '手电筒', '户外照明', '头灯', '营地灯', '帐篷灯',
        '潜水照明装备', '信号灯', '发光棒', '救生灯', '钓鱼灯', '滑翔伞', '风筝', '套锅', '户外炊具', '户外餐饮用品',
        '野餐篮', '鸡蛋蓝', '食品袋', '烧烤炉', '烤架', '挡风板', '野餐餐具', '野餐炉具', '调味盒', '调料瓶',
        '户外鼓风机', '野餐包', '户外餐具套装', '登山杖', '手杖', '手写板', '潜水装备', '潜水服', '潜水袜', '脚蹼',
        '潜水箱包', '潜水帽', '呼吸调节器', '探棒', '潜水仪表', '潜水电脑', '气瓶', '水下推进器', '潜水浮标',
        '配重和配重带', '潜水减压表', '呼吸管', '呼吸器', '潜水靴', '手蹼', '浮力调整器(BC)', '面镜', '船桨',
        '划艇配件', '水上船艇', '皮划艇充气艇', '龙舟', '帆船', '摩托艇', '独木舟', '指南针', '温度计', '气压计',
        '高度计', '通讯', '导航', '户外表类', '无线电', '对讲机', '通讯设备', '户外功能手表', '电子导航设备', '更衣',
        '沐浴帐篷', '帐篷', '天幕', '帐篷配件', '工程', '民用', '活动', '救灾帐篷', '遮阳篷', '雨篷', '车篷', '广告篷',
        '车顶帐篷', '露营', '旅游', '登山帐篷', '沙滩帐', '钓鱼遮阳帐篷', '雪杖', '滑雪装备', '滑雪眼镜', '滑雪专用包',
        '滑雪保养工具', '固定器', '滑雪手套', '滑雪头盔', '滑雪板', '滑雪鞋', '滑雪护具', '野餐垫', '户外休闲家具',
        '秋千', '户外营地车', '户外床', '折叠床', '吊床', '户外桌椅套装', '户外灯架', '户外椅子凳子', '充气床',
        '户外桌子', '户外活动', '线路', '旅游产品', '工兵斧', '营地斧', '刀具', '多用工具', '放大镜', '挂扣', '刀鞘',
        '刀套', '伞绳', '多功能组合工具', '军刀卡', '万能刀卡', '工兵铲', '工兵锹', '野营旅行小配件', '求生绳',
        '逃生绳', '防护', '救生装备', '防护口罩', '户外应急装备', '救生棒', '荧光棒', '求生锯', '绳锯', '线锯',
        '生存包', '信号镜', '防灾包', '防地震包', '防身报警器', '防护面罩', '急救毯', '保温毯', '求生哨', '应急包',
        '自救包', '野外沐浴袋', '太阳能沐浴袋', '饮水用具', '盛水容器', '户外烧水壶', '茶壶', '咖啡壶', '水桶', '水盆',
        '酒壶', '水壶', '水杯', '净水设备', '一次性浴缸袋', '洗漱清洁', '护理用品', '洗漱包', '旅行洗漱套装',
        '一次性床单被套', '旅行洗手液', '马桶垫', '毛巾', '雪地靴', '户外鞋靴', '溯溪鞋', '高海拔登山靴', '攀冰鞋',
        '登山鞋', '徒步鞋', '越野跑鞋', '户外休闲鞋', '多功能钳', '自行车修车工具', '补胎片', '润滑油', '洗链器',
        '多功能刀', '撬胎棒', '扳手', '截链器', '气门芯', '补胎胶水', '挫胎片', '螺丝刀', '修车架', '线剪钳',
        '山地自行车', '自行车整车', '电动平衡车', '智能自行车', '青少年学生车', '折叠自行车', '三轮车', '轻便车',
        '通勤自行车', '公路自行车', '母子车', '亲子车', '三人自行车', '旅行自行车', '死飞', 'BMX小轮车', '骑行服',
        '骑行服饰', '骑行鞋', '自行车手套', '束管带', '防风', '尘保暖面罩', '骑行头盔', '骑行袜', '骑行眼镜', '风镜',
        '自行车包', '自行车头巾', '货架', '尾架', '单车装备', '自行车水壶', '自行车贴纸', '反光贴', '自行车锁',
        '打气筒', '灯架', '灯夹', '自行车撑伞架', '自行车码表及配件', '自行车灯', '捆扎带', '车把带', '便携音响',
        '音箱', '单车护链贴', '自行车手机架', '防水地图袋', '水壶架', '车铃', '喇叭', '自行车车架', '自行车零',
        '自行车车头碗', '车圈', '刀圈', '自行车外胎', '自行车刹车装置', '泥除', '挡泥板', '自行车轮组', '坐垫', '鞍座',
        '曲柄', '自行车把套', '车条', '幅条', '牙盘曲柄中轴套装', '自行车把立', '中轴', '脚撑', '停车架', '骑行台',
        '自行车花鼓', '牙盘', '自行车车把', '车篮', '车筐', '座管', '座杆', '前叉', '避震装置', '自行车链条', '链条扣',
        '自行车飞轮', '变速器', '脚踏', '轴承', '滚珠', '自行车内胎', '电动车手机导航支架', '电动车装备区',
        '电动车挡风被', '电动车脚垫', '摩托车导航仪', '电动车GPS定位器', '电压转换器', '电动车手套', '护手',
        '电动车报警器', '电动车充电器', '电动车头盔', '摩托车点烟器', '电动车电池盒', '电动车锁', '电动车牌照框',
        '骑行防水鞋套', '电动车钥匙盖壳', '电动车音响', '电动车铃', '电动车撑伞架', '电动车防尘罩', '电动车定时器',
        '电动车贴', '电动车雨披', '电动车记录仪', '电池修复器', '电动车护膝', '电动车防晒衣', '电池修复液',
        '遮阳伞雨披', '电动车面罩', '摩托货架', '头盔镜片防雾剂', '电动车车载充电器', '摩托套锁', '电动车仪表壳',
        '电动车挂钩', '电动车遮阳伞', '增程器', '快速充电站', '摩托车充气泵', '瘪胎助推器', '电动车打气筒',
        '电动车防风镜', '自平衡电动车', '电动车整车', '电动滑板车', '老年代步车', '电动四轮车', '电动自行车',
        '电动摩托车', '电动轻便摩托车', '电动三轮车', '电动车开关', '电动车零', '电动车控制器', '电动车辐条',
        '电动车车篮', '电动车飞轮', '保险丝座', '电动车电池', '电动车后备箱', '电动车充电插座', '电动车前叉',
        '减震装置', '平衡车零配件', '电动车灯', '电动车坐垫', '电动车内胎', '电动车脚踏', '电动车碳刷', '刷架',
        '电动车外胎', '保险丝', '电动车刹车装置', '电动车轴承', '电机', '电动车反光镜', '电动车线类', '万用表',
        '电动车维修工具', '整车检测仪', '绝缘胶布', '拖车拖挂', '热缩管', '冷补胶', '焊锡丝', '除锈剂', '热熔枪',
        '电池检测仪', 'AB胶', '胶棒', '扎带', '电池夹', '橡胶锤', '电动车补胎工具', '控制器接头', '插接件', '电烙铁',
        '怀表', '立钟', '落地钟', '钟类', '挂钟', '座钟', '闹钟', '投影钟', '欧美腕表', '腕表', '多功能腕表',
        '瑞士腕表', '国产腕表', '日韩腕表', '茶烟', '替烟产品', '鼻烟', '电子烟配件', '国草', '电子烟', '潜水镜',
        '功能眼镜', '游泳镜', '运动眼镜', '滑雪镜', '3D眼镜', '机动车驾驶镜', '防蓝光镜', '夜视镜', '防辐射眼镜',
        '老花镜', '其它品牌打火机', '品牌打火机及配件', 'ZIPPO', '芝宝', '烟嘴', '烟具', '雪茄剪', '卷烟器', '烟盒',
        '太阳眼镜', '眼镜片', '光学眼镜', '定制成品光学镜', '眼镜架', '眼镜袋', '眼镜配件、护理剂', '眼镜清洁器',
        '眼镜护理剂', '眼镜盒', '眼镜鼻托', '眼镜防雾剂', '湿巾', '眼镜螺丝刀', '眼镜链', '镜布', '眼镜防滑耳套',
        '手镯', '链条', 'DIY配件', '弯管', '胸针', '首饰箱', '首饰收纳', '首饰盒', '首饰袋', '首饰展示架', '脚链',
        '发簪', '发饰', '发箍', '发夹', '发绳', '发圈', '婚庆饰品', '精选品牌', '项坠', '吊坠', '首饰套装', '项链',
        '手链', '饰品摆件', '戒指', '指环', '银饰', '耳饰', '其他银饰及银制品', '耳环', '耳线', '耳钉', '耳夹', '摆件',
        '颈饰', '危地马拉翡翠', '胸饰', '其他', '手饰', '黄金纪念币', '贵金属纪念币', '白银纪念币', '天然珍珠（新）',
        '多宝玉石', '其他天然玉石', '珠宝奇石', '手串', '挂件', '珠宝半成品', '把件', '车挂', '戒圈', '笔搁',
        '设计珠宝', '金石篆刻', '文玩木串', '茶杯', '茶碗', '茶盘', '茶盏', '茶叶盒', '高端紫砂', '茶宠', '盖碗',
        '花瓶', '茶案', '花盆', '茶叶罐', '高端陶瓷', '瓷片', '其它收藏品', '花草茶具', '茶道器具', '旅行茶具', '茶道',
        '零配', '冲茶器', '茶巾', '香炉', '茶滤', '茶托', '茶匙', '整套茶具', '功夫茶具', '公道杯', '茶海', '闻香杯',
        '茶宠摆件', '茶夹', '飘逸杯', '其他特色工艺品', '俄罗斯特色', '海外工艺品', '巴基斯坦特色', '越南特色',
        '北欧特色', '印度特色', '波西米亚特色', '泰国特色', '埃及特色', '仡佬族', '少数民族特色工艺品', '泥人', '泥塑',
        '面塑', '地区民间特色手工艺', '刺绣', '伊斯兰教工艺品', '宗教工艺品', '其他宗教工艺品', '道教工艺品',
        '基督教工艺品', '佛教工艺品', '剪纸', '手工艺', '民俗', '树脂', '内画鼻烟壶', '中国结', '布老虎', '葫芦制品',
        '景泰蓝', '皮影', '年画', '贝雕', '贝壳制品', '竹编', '竹雕', '砖雕', '漆器', '木偶', '木艺', '木雕', '石雕',
        '灯影', '石膏', '折扇', '扇子', '青花瓷', '藏香', '铁画', '蜡染印染', '骨雕', '骨制品', '梳篦', '牙雕',
        '牙制品', '脸谱', '葫芦', '竹制品', '十字绣', '窗花', '根雕', '门票', '票证', '标牌章', '纸片', '供应票',
        '证书', '单据', '交通票', '徽章', '纪念章', '佩件', '商标', '金融票', '教学挂图', '地图', '趣味收藏', '宣传画',
        '广告画', '生日报', '纸质纪念品', '香水瓶', '香水配件', '台历', '包袋', '挂历', '名人签名', '历史收藏',
        '球星球队周边收藏', '餐巾纸', '利是封', '贴纸', '其它趣味收集', '铜器', '金属', '搪瓷器具', '金器', '锡器',
        '集邮用具用品', '收藏品保养', '鉴定工具', '古玩鉴定', '保养工具', '手工艺品保养工具', '香插', '香道器具',
        '线香', '盘香', '香粉', '名贵花卉', '花鸟园艺', '名贵宠物', '黑胶唱片机', '西洋收藏品', '照相机', '花道器具',
        '日本画', '书法', '素描', '水彩', '唐卡', '色粉画', '油画', '漫画', '版画', '水粉', '国画', '信札', '中国书法',
        '丙烯画', '碑帖', '日本书道', '沉香', '香料', '手把件', '金丝楠', '小叶紫檀', '成品木串', '木带宝珠串',
        '黄花梨', '民国钱币', '现代花钱', '纪念券', '非流通外国钱币', '连体钞', '纪念钞', '非流通港澳台钱币',
        '外汇兑换券', '国库券', '钱币文创', '钱币收藏历史资料', '连环画', '古籍善本', '其它', '古董艺术品', '钻石首饰',
        '品牌首饰', '彩色宝石', '贵重宝石', '黄金首饰', '观赏石', '奇石', '矿物晶体', '酒具', '渔具', '古董家具',
        '瓷器', '旧藏邮品', '古董首饰', '文房用品', '茶叶', '佛教典籍', '古陶瓷', '老金属器', '其他收藏品', '床类',
        '红木家具', '箱类', '坐具类', '成套家具', '几类', '镜子类', '红木', '架类', '柜类', '桌类', '屏风', '花窗',
        '刀剑', '刀剑相关', '刀剑保养品', '剑架', '剑托', '剑袋', '成品石雕', '革命烈士遗物', '红色收藏', '雕塑摆件',
        '画像', '字画', '其他宗教收藏', '宗教用品', '宗教服务及其用品', '佛像', '神像', '罗盘', '佛牌', '老兵器',
        '历代武器', '古玩杂项', '录音机', '相机', '海绵宝宝主题收藏', '主题收藏', '雀巢主题收藏', '可口可乐主题收藏',
        '奥运主题收藏', 'hello kitty主题收藏', '麦当劳主题收藏', 'M&M主题收藏', '肯德基主题收藏', '变形金刚主题收藏',
        '迪士尼', '卡通主题收藏', '机器猫', '哆啦A梦主题收藏', '星巴克主题收藏', '百事可乐主题收藏', '芭比娃娃主题收藏',
        '印石章料', '篆刻|拓片', '古生物化石', '陨石', '臂搁', '水盂', '砚滴', '砚屏', '砚台', '外国邮票', '邮品',
        '中国邮票', '港澳台邮票', '凤眼菩提', '菩提', '核桃', '猴头核桃', '龙眼菩提', '麒麟眼菩提', '金刚菩提',
        '白玉菩提', '佛心果', '滴血莲花菩提', '柏香籽', '百香籽', '库克', '藤艺', '椰蒂', '紫金钵盂菩提', '星月菩提',
        '桃核', '佛螺菩提', '橄榄核', '文玩核桃', '五线菩提', '紫金鼠', '莲花菩提', '千眼菩提', '草珠菩提', '菩提根',
        '象牙果', '定制石英质玉', '玛瑙玉髓', '定制玉石', '定制岫玉（蛇纹石玉）', '定制多宝', '定制和田玉',
        '定制琥珀蜜蜡', '定制绿松石', '定制南红', '定制珍珠', '定制首饰彩宝', '定制足金首饰（素款）', '定制K金（素款）',
        '定制彩色宝石', '定制铂金', 'PT（素款）', '定制钻石首饰', '定制银饰', '定制书法', '定制书画篆刻', '定制西画',
        '定制国画', '定制篆刻', '定制工艺画', '定制版画', '定制石雕', '定制文玩', '定制家具', '定制木作', '定制木串',
        '定制摆件', '定制核雕', '投资贵金属', 'k金（素款）', '脚饰', '裸钻', '戒托', '其他彩色宝石', '投资金', '投资银',
        '合成（处理）钻石耳饰', '人工宝石', '处理宝石', 'k金镶嵌人工', '合成（处理）钻石手饰', '合成（处理）钻石颈饰',
        '铂金镶嵌人工', '莫桑石', '合成锆石胸饰', '合成锆石耳饰', '合成锆石颈饰', '天然水晶', '当代紫砂拍卖',
        '当代珍品拍卖', '木作杂项拍卖', '玉石拍卖', '茶叶拍卖', '搪瓷器具拍卖', '当代邮品拍卖', '趣味收藏拍卖', '手办',
        '公仔', '当代金石篆刻拍卖', '当代陶瓷拍卖', '珠宝拍卖', '当代钱币拍卖', '当代书画拍卖', '西洋收藏品拍卖',
        '古董艺术品拍卖', '古钱币拍卖', '古陶瓷拍卖', '古籍善本拍卖', '金石篆刻拍卖', '老金属器拍卖', '文房用品拍卖',
        '邮品拍卖', '古董家具拍卖', '绘画拍卖', '紫砂拍卖', '古董首饰拍卖', '文玩木串拍卖', '面部精油', '纯露',
        '面部护肤', '面部磨砂', '去角质', '化妆水', '爽肤水', '法令纹贴', '液态精华', '贴片面膜', '涂抹面膜', '洁面皂',
        '洁面产品', '卸妆油', '卸妆水', '卸妆啫喱', '卸妆巾', '安瓶', '原液', '粉状精华', '乳液', '面霜',
        '面部护理套装', '喷雾', '面颈一体', '挂耳式颈膜', '面部按摩霜', '医学美容服务虚拟卡券', '美容服务',
        '生活美容服务实体卡券', '生活美容服务虚拟卡券', '美容SPA', '医学美容服务实体卡券', '鼻贴', 'T区护理',
        'T区护理套装', '鼻膜', '黑头导出液', '防晒喷雾', '防晒', '防晒霜', '唇部护理套装', '唇部护理', '有色润唇膏',
        '唇部精华', '唇部磨砂', '润唇啫喱', '唇膜', '眼膜', '眼部护理', '眼部护理精华', '眼胶', '啫喱', '眼霜',
        '眼部护理套装', '美妆礼品卡', '男士须后水', '男士护肤', '男士防晒', '剃须啫喱', '剃须膏', '剃须泡', '男士喷雾',
        '男士爽肤水', '男士面部精华', '男士唇部磨砂膏', '男士颈霜', '男士润唇膏', '男士眼部美容胶', '男士护理套装',
        '男士眼部精华', '男士眼膜', '男士颈膜', '男士面部磨砂膏', '男士精油', '男士鼻贴', '男士面膜', '男士唇膜',
        '男士眼霜', '男士洁面', '男士面部乳霜', '男士唇部精华', '美白丸', '口服', '美容护肤体验装', '旅行装', '体验装',
        '美容护肤便携装', '隔离', '妆前', '面部彩妆', '气垫', '定妆喷雾', '高光', '腮红', '胭脂', '粉饼', '修容',
        '阴影', '遮瑕', '素颜霜', 'BB霜', '粉底液', 'CC霜', '蜜粉', '散粉', '其他彩妆', '其他器材配件', '美体工具',
        '蜡疗机', '手蜡机', '美体瘦身配件', '非仪器类脱毛工具', '唇笔', '唇线笔', '唇部彩妆', '唇彩', '唇蜜', '唇釉',
        '有色唇膏', '口红', '香膏', '香水套装', '试香工具', '身体彩妆', '假睫毛胶水', '美妆蛋', '化妆海绵',
        '双眼皮胶水', '镊子', '电动修眉刀', '双眼皮贴', '刷包', '面膜碗', 'DIY面膜工具', '修眉刀', '睫毛卷翘工具',
        '睫毛夹', '洗脸刷', '化妆刷', '卸妆棉', '化妆棉', '面扑', '粉扑', '假睫毛', '化妆套刷', '化妆', '美容工具',
        '吸油纸', '假睫毛辅助工具', '男士眼影', '男士彩妆', '男士隔离', '男士遮瑕', '男士眉笔', '眉粉', '眉膏',
        '男用卸妆', '男士BB霜', '男士粉底', '男士睫毛膏', '睫毛底膏', '男士腮红', '男士高光', '男士阴影',
        '男士彩妆套装', '男士粉饼', '男士眼线', '男士有色唇膏', '男士蜜粉', '美容修剪工具', '面部美容工具', '洁面工具',
        '瘦脸机', '瘦脸工具', '洁面仪', '面部塑形按摩工具', '毛孔清洁工具', '其它面部美容工具配件', '压缩面膜',
        '面膜纸', '美眼工具', '美容喷雾工具', '蒸脸工具', '美容修剪器', '彩妆套装', '彩妆盘', '男士香水', '眉毛雨衣',
        '眼部彩妆', '眉笔', '眼影', '卧蚕笔', '眼线', '睫毛膏', '美甲工具', '指甲油', '美甲产品', '护理美甲器',
        '指甲贴', '其他美甲产品', '黑头仪', '面部美容仪器', '电子美容仪', '鼻梁增高器', '美容喷雾机', '蒸脸器',
        '睫毛卷翘器', '脱毛仪', '美体仪器', '彩色隐形眼镜', '其他医疗器械工具', '脱毛仪（器械）', '美容美体护理仪（器械）',
        '面部清洁护理仪（器械）', '多功能皮肤美容仪（器械）', '祛疤贴', '祛疤', '修复', '祛疤膏', '凝胶', '其他敷料',
        '医用敷料', '透明质酸敷料', '抗菌敷料', '医用冷敷贴', '胶原蛋白敷料', '消毒喷雾', '消毒用品', '消毒液',
        '消毒泡腾片', '消毒凝胶', '鞋袜干爽剂', '室内除臭', '芳香用品', '空气清新', '净化', '芳香剂', '除臭喷雾',
        '除臭用品', '空气净化剂', '冰箱除味剂', '鞋袜除臭剂', '干燥剂', '面部清洁', '润唇膏', '面膜',
        '假牙及牙套清洁片', '口腔护理', '牙膏', '牙线', '牙线棒', '牙齿美白脱色剂', '口腔护理套装', '牙粉', '漱口水',
        '口鼻清洁杀菌消炎剂', '护牙素', '口腔清新剂', '牙刷', '口腔清洁工具', '内衣皂', '内衣洗涤剂', '衣物清洁剂',
        '护理剂', '衣物清洁慕斯', '衣物除菌剂', '洗衣液', '衣领净', '彩漂', '衣物柔顺剂', '衣物清洁泡泡', '洗衣皂',
        '洗衣凝珠', '洗衣粉', '真丝羊毛等特殊材质洗衣液', '漂白剂', '干洗剂', '织物喷雾', '靴干洗剂', '吸色片',
        '留香珠', '即时去渍剂', '衣物冷感喷雾', '手洗洗衣液', '洗护套装', '头发清洁', '摩丝', '发膜', '护发产品',
        '护发素', '洗发水', '砧板喷雾', '家庭环境清洁剂', '空调清洁剂', '果蔬专用清洁剂', '餐具光亮剂', '马桶清洁剂',
        '洁厕剂', '家用除霉剂', '灯具清洁剂', '洗衣机槽清洁剂', '运动器材清洁剂', '家庭清洁慕斯', '泡泡', '洁厕凝胶',
        '家电清洁剂', '洗衣机槽泡腾片', '织物染色剂', '水垢清洁剂', '除垢剂', '管道疏通剂', '墙纸', '墙面',
        '涂鸦清洁剂', '地面清洁剂', '浓缩洗洁精', '油污清洁剂', '不锈钢清洁剂', '化妆工具清洁剂', '布艺用品清洁剂',
        '纱窗清洁剂', '洁瓷剂', '杯具', '茶壶清洁剂', '洗洁精', '玻璃清洁剂', '清洁剂套装', '洗碗机用洗涤剂',
        '家庭除菌喷雾', '多用途清洁剂', '香薰香料', '香薰用品', '香薰蜡烛', '手帕纸', '纸品', '棉柔巾', '洗脸巾',
        '湿厕纸', '家用防油贴纸', '保湿纸巾', '厨房纸巾', '抽纸', '一次性洗脸巾', '大盘卷纸', '卷筒纸', '平板卫生纸',
        '擦手纸', '卫生纸', '口腔服务', '个护服务', '美发沙龙服务', '身体护理服务', '衣物鞋类清洁泡泡', '慕斯',
        '清洁泡泡', '经期清洁巾', '卫生棉条', '私处香氛', '家庭环境清洁泡泡', '裤型卫生巾', '私处洗液', '护垫',
        '护足霜', '身体护理', '足部磨砂膏', '护手霜', '身体乳液', '足贴', '清凉油', '防暑', '醒神药油', '浴足剂',
        '身体磨砂膏', '去角质膏', '足浴盐', '花露水', '爽身粉', '成人用纸尿护理用品', '中老年护理用品', '香皂',
        '身体清洁', '搓泥浴宝', '浴液', '洗手液', '泡澡药包', '泡澡花瓣', '沐浴露', '浴盐', '地面保养剂', '家私',
        '皮具护理品', '家私清洁', '地毯干洗剂', '皮具皮革护理剂', '防虫', '防蚊用品', '驱虫用品', '灭蟑香', '蚊香盘',
        '止痒膏', '凝露', '蚊香加热器', '除螨喷雾', '电蚊香套装', '家用杀虫剂', '防霉防蛀片', '驱蚊剂', '蚊香液',
        '杀虫剂', '驱蚊喷雾', '走珠', '蚊香片', '男士洗发水', '男士美发护发', '假发', '男士护发素', '男士洗护套装',
        '指甲修护乳', '手部护理', '手部保养套装', '手部磨砂', '手膜', '护理精油', '身体精油芳疗', '香薰工具',
        '精油工具', '器皿', '男士沐浴露', '男士身体护理', '男士爽身粉', '男士身体乳', '男士脱毛膏', '男士身体磨砂膏',
        '男士私处护理', '纤体绷带', '身体乳', '精油', '清凉止痒', '防暑醒神膏', '暖宝宝', '肩颈', '膝肘贴', '暖手贴',
        '保暖贴', '身体喷雾', '男士止汗露', '止汗露', '消臭剂', '洗眼液', '纤体霜', '脱毛膏', '身体皂', '颈霜', '颈膜',
        '身体护理套装', '其他美发工具', '染发烫发', '其它染发烫发产品', '美发笔', '线下沙龙服务', '染发膏', '染发产品',
        '胸部护理工具', '胸部护理', '胸部护理精华', '乳霜', '牙签', '牙齿美白', '口腔护理配件', '口腔喷剂', '洁牙粉',
        '私处护理', '私处保养', '私护湿巾', '假发配件（护理液', '发网', '支架）', '假发及配件', '假发发箍', '发包',
        '丸子', '马尾', '整顶假发', '刘海片', '帽子假发', '假发用具', '挂耳染', '补发片', '洗发护发', '护发精油',
        '其它护发', '头皮护理', '焗油手套', '个护用具', '耳勺', '沐浴按摩用品', '塑身贴', '塑形带', '焗油围布', '喷瓶',
        '面霜分装瓶', '卷发棒', '镜梳套装', '手动剃须刀', '穿戴甲', '美甲贴配饰', '发贴', '剃须刀', '焗油耳罩',
        '蒸汽眼罩', '指甲钳', '焗油帽子', '按摩棒', '按摩穴位棒', '沐浴球', '造型板', '焗油梳子', '矫姿用品及配件',
        '女用剃毛刀', '焗油碗', '焗油用具', '女用手动剃毛刀', '搓脚板', '洗脚刷', '磨脚石', '棉签', '棉棒', '棉包',
        '发带', '剃须刀片', '梳子', '化妆梳', '按摩梳', '剃须刀架', '刀片', '干发帽', '修甲剪刀', '美甲贴套装',
        '旅行剃须刀', '按摩刮疗片', '浴擦', '浴刷', '美甲', '修甲套装', '浴帽', '其它个护工具', '剃须清洁刷',
        '其它美甲工具', '其他焗油用品', '盘发器', '隐形眼镜伴侣', '滴眼液、护眼用品', '隐形眼镜伴侣盒', '其他眼部护理',
        '足部护理', '足霜', '足部磨砂', '足膜', '药包', '免洗洗手液', '鼻腔清洁及用具', '硬镜护理用品', '眼部保健',
        '医用眼部护理产品', '硬性接触镜', '艾滋病检测试纸', '排卵卡笔', '排卵检测仪', '润滑剂', '避孕套', '性保健用品',
        '验孕棒', '验孕仪器', '烘焙原料', '辅料', '食品添加剂', '其它调味品', '果酱', '沙拉', '腌菜', '榨菜', '酱菜',
        '泡菜', '寿司料理', '料理调料', '豆腐乳', '轻食简餐', '牛油果油', '食用油', '调味油', '米糠油', '花椒油',
        '葡萄籽油', '大豆油', '花生油', '鱼露', '葵花籽油', '核桃油', '菜籽油', '蚝油', '玉米油', '香油', '红花籽油',
        '山茶油', '亚麻籽油', '火麻油', '橄榄油', '调和油', '椰子油', '麦类粉', '面粉', '杂粮', '食用粉', '其它粮食',
        '薯类粉', '米类粉', '豆类粉', '杂粮粉', '玉米', '其他食品', '速食汤', '方便速食', '冷藏食品', '即食火锅',
        '其他方便食品', '面条', '挂面（待煮面条）', '意大利面', '即食腌菜', '人造肉', '植物肉速食', '方便面', '拉面',
        '面皮', '面饼', '方便米饭', '方便粉丝', '米线', '螺蛳粉', '速食粥', '冷面', '粽子', '罐头', '即食肉类',
        '速食肠类', '寿司', '饭团', '糕点提货券', '糕点', '点心', '面包', '新鲜蛋糕', '低温糕点', '短保烘焙', '月饼',
        '蛋卷点心', '曲奇糕点', '月饼提货券', '海参即食', '即食水产', '海味零食', '小龙虾零食', '即食鱿鱼零食',
        '即食海蜇', '海带零食', '蟹系列', '即食鱼零食', '海苔系列', '即食虾零食', '贝系列', '千张', '豆干制品',
        '蔬菜干', '素肉', '素鸡', '魔芋制品', '面筋制品', '臭豆腐', '豆腐干', '香蕉干', '蜜饯', '果干', '水果制品',
        '桃干', '菠萝', '凤梨干', '柚脯', '柚干', '薯类制品', '芋头条', '车厘子干', '黄皮', '榴莲干', '哈密瓜干',
        '水果罐头', '加应子', '李子', '樱桃干', '苹果干', '蔬果干', '混合果干', '蔓越莓干', '枣类制品', '佛手果',
        '柿饼', '冻干制品', '芭蕉干', '蓝莓干', '玫瑰花脯', '罗汉果', '橄榄', '海棠果', '椰子片', '无花果干', '草莓干',
        '槟榔', '圣女果干', '芒果干', '陈皮', '梅类制品', '柠檬干', '猕猴桃干', '菠萝蜜', '桑椹干', '杏仁', '杏干',
        '木瓜', '山楂类制品', '桂花酱', '菊花酱', '槐花酱', '玫瑰花酱', '葡萄干', '金桔类制品', '笋类制品', '酸角',
        '南瓜干', '喜蛋', '饼干', '膨化', '喜饼', '诞生礼饼', '巧克力酱', '巧克力', '黑巧克力', '白巧克力',
        '饼干巧克力', '松露巧克力', '牛奶巧克力', '巧克力制品', '混合巧克力', '夹心巧克力', '手工巧克力', '果仁巧克力',
        '健身轻食肉制品', '肉干肉脯', '熏腊卤味', '肉类熟食', '驴肉', '兔肉干', '兔丁', '卤味素食', '猪肉类', '羊肉类',
        '人造肉零食', '鸽肉类', '鹌鹑类', '鸡肉零食', '鹅肉类', '即食卤味', '盐焗蛋', '骆驼肉', '肉类礼包', '组合',
        '鸭肉零食', '牛肉类', '白果', '银杏果', '山核桃', '炒货', '豆类制品', '长寿果', '碧根果', '榛子', '纸皮',
        '薄皮核桃', '松子', '瓜子', '即食板栗', '腰果', '鲍鱼果', '花生', '夏威夷果', '香榧', '混合坚果', '核桃仁',
        '坚果礼盒', '礼包', '巴旦木', '小银杏', '坚果制品', '开心果', '地方特产', '果冻', '布丁', '糖果零食', '喜糖',
        '口香糖', '糖果', '冰淇淋', '驼奶片', '驼奶及驼奶粉', '驼奶', '驼奶粉', '奶干', '奶酪', '奶制品', '奶酥',
        '奶片', '奶皮', '牦牛奶', '乳制品', '低温乳制品', '调制乳（风味奶）', '酸奶', '水牛奶', '纯牛奶', '酸奶粉',
        '羊奶', '含乳饮料', '豆奶', '豆浆', '植物蛋白饮料', '饮料', '茶饮料', '饮用水', '果味', '风味饮料', '凉茶',
        '即饮咖啡', '碳酸饮料', '气泡水', '植物饮料', '功能饮料饮品', '健康饮料饮品', '酸梅汤', '胶囊咖啡', '速溶咖啡',
        '咖啡豆', '咖啡液', '咖啡礼盒', '其它饮品', '青汁', '食补粉', '抹茶粉', '其他粉粉', '葛根粉', '薏米粉',
        '天然粉粉食品', '杏仁粉', '芝麻粉', '代餐粉', '椰子粉', '果蔬粉', '谷物营养配方粉', '冲饮冻干粉', '藕粉',
        '冲饮品', '豆奶粉', '茶粉', '茶浓缩液', '速溶茶', '冻干茶', '酸梅粉', '可可', '巧克力饮品', '冲饮果酱', '花酱',
        '双皮奶', '姜汁撞奶', '冲饮果汁', '冲饮果味粉', '袋泡茶', '蜂蜜果味茶', '姜汤', '冲饮姜粉', '普通固体饮料',
        '冲饮红糖', '芝麻糊', '冻干粉', '块冲饮', '绵羊奶粉', '全家营养奶粉', '羊奶粉', '牛奶粉', '牦牛奶粉', '黄茶',
        '生茶', '普洱', '熟茶', '年份茶', '老茶头', '碎银子', '柑普', '小青柑', '高端品牌', '祁门红茶', '红茶', '锡兰',
        '阿萨姆', '大吉岭', '进口红茶', '正山小种', '金骏眉', '其它红茶', '滇红', '普洱提货券', '茶提货券',
        '绿茶提货券', '乌龙茶提货券', '代用', '花草茶', '花草', '水果', '再加工茶', '花果果粒茶', '陈皮茶', '菊花茶',
        '玫瑰花茶', '茉莉花茶', '莓茶', '组合型花茶', '六堡茶', '黑茶', '其它黑茶', '安化黑茶', '高端绿茶', '高端茗茶',
        '高端黑茶', '高端白茶', '高端岩茶', '高端普洱', '凤凰单丛', '乌龙茶', '岩茶', '黑乌龙', '肉桂茶', '台湾高山茶',
        '铁观音', '其它乌龙茶', '大红袍', '太平猴魁', '绿茶', '西湖龙井', '松阳香茶', '六安瓜片', '安吉白茶',
        '峨眉山茶', '日照绿茶', '黄山毛峰', '碧螺春', '龙井茶（非西湖）', '其它绿茶', '信阳毛尖', '多品种茶叶礼盒',
        '茶膏', '茶精', '白毫银针', '白茶', '白牡丹', '其它白茶', '寿眉', '贡眉', '国产白酒', '起泡及香槟葡萄酒',
        '葡萄酒', '加强葡萄酒', '干红静态葡萄酒', '桃红静态葡萄酒', '国产葡萄酒', '甜型葡萄酒（含贵腐', '冰酒）',
        '干白静态葡萄酒', '进口葡萄酒', '露酒', '果酒', '养生酒', '其他酒类', '收藏酒', '国产白兰地', '洋酒', '朗姆酒',
        '进口威士忌', '龙舌兰', 'Tequila', '白兰地', 'Brandy', '梅酒', '进口白兰地', '清酒', '烧酒', '国产威士忌',
        '威末', 'Vermouth', '伏特加', 'Vodka', '威士忌', 'Whiskey', '预调鸡尾酒', 'Alcopop', '力娇酒', 'Liqueur',
        '金酒', '啤酒', '米酒', '黄酒', '传统黄酒', '营养包', '海外膳食营养补充食品', '丽人海外膳补', '功能饮品',
        '普通膳食营养食品', '功能糖果', '松花粉', '药食同源食品', '酸枣仁', '甘草', '蚂蚁', '牛蒡', '决明子', '桑叶',
        '银杏', '桔梗', '金银花', '川贝', '砂仁', '鸡内金', '鱼腥草', '芡实', '风流果', '其他药食同源食品', '桑椹',
        '紫苏', '天门冬', '黄芩', '荷叶', '胖大海', '藏红花', '芦荟', '葛根', '茯苓', '龙眼肉（桂圆）', '肉桂', '百合',
        '当归', '白扁豆', '黄精', '沙棘', '沙棘原浆', '玫瑰茄', '洛神花', '佛手', '橘皮', '栀子', '蜂蜜卡券',
        '蜂蜜及其制品', '蜂蜜', '天麻', '滋补养生原料', '其它新食品原料类', '花生衣', '不老草', '广金钱草', '制何首乌',
        '牛膝', '皂角米', '生地黄', '传统滋补品其他', '蛹虫草', '化橘红', '北沙参', '玛咖干', '五加皮', '太子参',
        '金蝉花', '威灵仙', '黄芪', '豆蔻', '罗布麻', '熟地黄', '珍珠粉', '辣木籽', '丹参', '桃胶', '益母草', '五味子',
        '雪燕', '红花', '麦冬', '养生泡酒料', '党参', '杜仲', '山茱萸', '枸杞原浆', '枸杞制品', '枸杞及其制品', '枸杞',
        '知母', '滋补经典方', '姜半夏', '板蓝根', '蒲公英', '补骨脂', '升麻', '贝母类', '狗脊', '焦山楂', '炙甘草',
        '鹿角霜', '车前草', '紫苏类', '墨旱莲', '连翘(老翘)', '粉萆薢', '石决明', '柴胡', '芦根', '芥子', '葫芦巴',
        '土牛膝', '川牛膝', '淡豆豉', '红花类', '白术', '玉米须', '槐花', '萹蓄', '槐米', '鸡血藤', '藿香', '辛夷',
        '荆芥穗', '土茯苓', '桃花', '珍珠母', '淡竹叶', '仙鹤草', '醋三棱', '火麻仁', '法半夏', '精制中药材', '养生茶',
        '冬虫夏草', '石斛', '枫斗', '养生膏', '食疗滋补营养', '五谷养生营养品', '紫米', '养生丸', '山药', '滋补礼盒',
        '滋补凉茶', '龟苓膏', '滋补营养糖', '药膳养生汤料', '三七', '鹿制膏', '鹿制品', '鹿茸', '鹿茸枝', '鹿茸片',
        '灵芝粉', '灵芝', '灵芝片', '整枝灵芝', '其它灵芝产品', '灵芝孢子粉', '西洋参', '参类滋补品', '山参', '苦参',
        '红参', '人参', '园参及其制品', '高丽参及其制品', '花胶', '鱼胶礼盒', '参茸贵细', '即食花胶', '鱼胶', '海马',
        '参茸贵细卡券', '元贝', '红景天', '阿胶块', '阿胶膏方', '阿胶制品', '阿胶浆', '阿胶膏', '固元膏', '阿胶原粉',
        '燕窝制品', '燕窝滋补品', '燕窝', '即食燕窝', '燕窝卡券', '优惠或服务类卡券', '储值卡券', '提货', '兑换卡券',
        '维矿物质', '感冒咳嗽', '皮肤科用药', '肠胃用药', '补益安神', '鲜沙参', '蔬菜', '蔬菜制品', '芦笋', '鲜人参',
        '山葵', '莲子', '豆制品', '其他蔬菜', '莴笋', '叶菜类', '蔬菜组合', '蔬菜礼盒礼篮', '笋制品', '半加工蔬菜',
        '冬瓜', '净菜', '板栗', '锥栗', '土豆', '芋头', '芋艿', '其他根茎类', '本地配蔬菜', '白果（银杏）', '萝卜',
        '甜菜头', '西式调料菜', '荸荠', '马蹄', '新鲜豇豆', '丝瓜', '凉菜', '凉拌菜', '鲜花椒', '番薯', '其他茄果瓜类',
        '菱角', '豆类（新鲜）', '辣椒', '茄子', '南瓜', '鲜牛蒡', '苦瓜', '洋葱', '新鲜蒜苔', '新鲜莲蓬', '腌制蔬菜',
        '秋葵', '西红柿', '番茄', '圣女果', '黄瓜', '食用玫瑰', '胡萝卜', '佛手瓜', '桦树茸', '鲜天麻', '西兰花',
        '花菜', '西葫芦', '小龙虾', '海鲜水产及制品', '甲鱼', '海产干货', '海鲜制品', '海鲜丸料', '海胆', '章鱼',
        '鱿鱼', '乌贼', '海兔', '西式烘培', '低温意大利面', '冷藏', '冷冻食品', '冷冻粽子', '冷冻面条', '纳豆',
        '冷冻面包', '蛋糕', '芋圆', '面点组合', '礼盒', '年糕', '糍粑', '汤圆', '元宵', '石榴', '草莓', '苹果',
        '百香果', '西柚', '蔓越莓', '姑娘果', '灯笼果', '树莓', '椰青', '哈密瓜', '芭乐', '番石榴', '无花果', '西梅',
        '柿子', '奇异莓', '甘蔗', '车厘子', '樱桃', '蓝莓', '液氮', '冷冻榴莲', '柠檬', '香蕉', '本地配水果', '黑莓',
        '葡萄', '提子', '火参果', '蛇皮果', '毛丹', '毛荔枝', '橙子', '芒果', '山楂', '荔枝', '枇杷', '桑葚', '凤梨',
        '莲雾', '燕窝果', '杨桃', '柿子制品', '冷冻水果', '水果衍生品', '杨梅', '火龙果', '水果礼盒', '柚子', '鲜枣',
        '龙眼', '黄皮果', '西瓜', '青梅', '更多水果', '山竹', '奇异果', '猕猴桃', '释迦', '牛油果', '雪莲果', '甜瓜',
        '人参果', '鲜榴莲', '风味烧烤', '健身餐', '凉拌肉类', '半成品菜', '方便菜', '快手菜', '速食菜', '花椒鸡',
        '烧烤半成品', '羊蝎子', '关东煮', '火锅半成品', '其他半成品菜', '冷冻薯条', '驴肉制品', '猪牛羊禽肉及制品',
        '更多肉类', '鹅肉', '肉制品', '烘焙蛋糕卡券', '生鲜卡券', '生肉', '肉制品卡券', '低温乳品', '冰淇淋卡券',
        '冷冻卡券', '水果卡券', '海鲜', '水产品', '制品卡券', '蔬菜制品卡券', '半成品菜卡券', '大闸蟹卡券',
        '蛋制品卡券', '低温奶', '奶酪黄油', '永生花', '干花', '花材', '生活鲜花', '周期订阅鲜花', '鲜花卡', '花架',
        '花器', '花架\t', '花几', '花篮', '栅栏', '创意绿植', '花卉', '微景观', '绿植盆栽', '花园植物', '行道树',
        '果树', '仿真花', '仿真饰品', 'DIY仿真材料', '仿真植物盆景', '花艺套餐', '仿真水果', '假花', '花瓣', '干花包',
        '干树枝', '园艺用品', '鲜果篮(预定与速递)', '打草绳等其他绳子', '花卉药剂', '高端园艺用品', '洒水', '浇水壶',
        '智能园艺用品', '塑料薄膜', '美植袋', '园艺袋', '微喷', '滴灌', '接头类', '其他园艺用品', '盆景石', '园艺手套',
        '育苗盘', '营养钵', '花园管', '软管', '包纱管', '园艺假山', '小型喷雾壶', '水晶珠', '玻璃珠', '大型篱笆',
        '花园水泵', '草坪种子', '蔬果', '蔬果种子', '种球', '花卉种子', '花店零批', '商务用花', '上门送花', '绿植',
        '多肉植物', '高端盆景', '盆栽', '大型绿植', '成品组合盆栽', '卡通花', '创意花', '婚礼鲜花布置', '果树（苗）',
        '行道树（苗）', '花艺包装', '材料', '制作材料', '制作工具', '仿真绿植', '蔬果成品', '仿真果蔬', '追悼',
        '奠仪用花', '园艺设计服务', '新娘手捧花', '婚车鲜花', '鲜花拱门', '胸花', '婚庆花篮', '玫瑰花瓣',
        '鲜花速递(同城)', '插花培训', '兽用非处方药', '养殖设备', '养殖服务', '水产养殖物资', '饲料', '蜂场养殖物资',
        '动物保健品', '水质调节剂', '篷布', '遮网', '大棚', '农业传感器', '农业物联网', '农业气象监测站',
        '动物电子耳标', '农田杀虫灯', '虫情监测系统', '虫情测报灯', '智慧农业系统', '农用机器人', '农用无人机',
        '农业机械', '耕种机械', '施肥机械', '收割机械', '农用拖拉机', '农机配件', '植保机械', '农产品采后加工', '包装',
        '贮藏', '农业工具', '喷灌', '滴灌设备', '温室大棚配件', '农药', '农技服务', '助剂', '添加剂', '动物种苗',
        '微生物菌剂', '有机肥', '肥料', '单质钾肥', '水溶肥', '叶面肥', '复合肥', '掺混肥', '单质磷肥', '单质氮肥',
        '微生物肥料', '农业生物用品', '农用', '环境用卫生农药', '粮食种子', '种子', '种苗', '草本种苗', '园林养护物资',
        '驱鸟剂', '授粉蜂', '杀菌剂', '杀螨剂', '杀螺剂', '除草剂', '农药助剂', '植物生长调节剂', '杀线虫剂',
        '儿童演出服', '儿童旗袍', '儿童文胸', '儿童POLO衫', '连身衣', '爬服', '哈衣', '裙子', '儿童运动裤',
        '儿童户外服', '儿童速干裤', '儿童滑雪裤', '儿童冲锋衣', '儿童运动衣', '儿童速干衬衫', '儿童抓绒衣',
        '儿童运动套装', '儿童冲锋裤', '儿童滑雪服', '儿童皮肤衣', '儿童速干T恤', '儿童软壳裤', '儿童软壳衣', '反穿衣',
        '罩衣', '校服', '校服定制', '儿童礼服', '泳衣裤', '儿童泳装', '儿童泳帽 ', '亲子时装', '儿童装饰手表',
        '儿童配饰', '儿童戒指', '太阳镜', '包包', '背带', '儿童耳饰', '儿童袜子(0-16岁)', '婴儿礼盒', '披风', '斗篷',
        '羽绒连体衣', '羽绒服饰', '羽绒内胆', '防抓手套', '护脚', '护膝', '口罩', '脚套', '耳暖', '袖套',
        '多件套 帽子、围巾、手套等组合', '儿童牛仔外套', '儿童牛仔', '儿童牛仔衬衫', '儿童牛仔裤', '儿童牛仔裙', '棉袄',
        '呢大衣', '大衣', '小西装', '普通外套', '仿皮草', '儿童家居服', '家居服上装', '家居服连体衣', '家居袍',
        '家居裙', '儿童内衣裤', '秋衣裤', '儿童和服', '肚围', '护脐带', '水晶', '水钻鞋', '婴儿步前鞋', '袜鞋',
        '儿童轮滑鞋', '儿童运动用品', '儿童运动包', '儿童护具', '雨靴', '鞋配件', '其他鞋配件', '量脚器', '儿童鞋带 ',
        '学步鞋', '儿童雨鞋套', '舞蹈鞋', '传统布鞋', '手工编织鞋', '皮靴', '棉靴', '棉鞋', '骨盆带', '束缚带',
        '盆骨带', '塑身裤', '束腹带', '待产用品', '清洁棉', '一次性内裤', '看护垫', '一次性床垫', '产妇卫生巾',
        '护腰枕', '成人尿裤', '托腹带', '保胎带', '待产包', '孕妇马桶', '座便器', '孕产妇湿巾', '一次性马桶垫纸',
        '产妇护垫', '乳晕护理', '乳房护理', '乳房喷雾', '乳头保护罩', '乳房乳霜', '乳房护理套装', '乳头矫正',
        '乳房精华', '乳房精油', '乳房冷热敷', '孕产妇DHA', '孕产妇营养品', '孕产妇多元营养', '孕产妇鱼肝油',
        '产后塑身品', '孕产妇保健食品', '孕产妇牛初乳', '孕产妇益生菌', '孕产妇防便秘营养品', '孕产妇钙铁锌',
        '孕产妇叶酸', '孕产妇维生素', '孕产服务（电子兑换券方式）', '防溢乳垫', '哺乳用品', '哺乳枕', '母乳储存保鲜',
        '背婴带', '孕产妇奶粉', '秋衣裤套装', '家居服', '哺乳装', '哺乳吊带', '哺乳衣', '月子服', '秋裤', '秋衣',
        '影楼服装', '孕妇礼服', '孕妇婚纱', '孕产妇护肤', '洗护', '祛纹', '纤体紧致', '孕产妇护发', '淡疤护理',
        '腿脚舒缓', '孕产妇洗发护发套装', '面部精华', '美容胶带', '面部套装', '洁面', '孕产妇洗发', '妊娠纹护理',
        '孕产妇腹膜', '月子牙刷', '孕期口腔护理', '孕产妇漱口水', '孕产妇牙膏', '吸奶器', '吸奶器配件', '孕妇鞋',
        '产妇帽', '孕妇袜', '产妇头巾', '连裤袜', '防辐射吊带', '防辐射', '防辐射布料', '防辐射肚兜', '护胎宝',
        '防辐射套装', '防辐射马甲', '防辐射手机袋', '卡袋', '其它防辐射', '防辐射面罩', '防辐射裙', '防辐射内裤',
        '防辐射口罩', '防辐射卡', '防辐射围裙', '孕产妇铃铛', '孕期胎教', '胎教仪', '哺乳文胸', '产检裤',
        '(文胸-内裤)套装', '背扣', '生理裤', '胸垫插片', '孕妇瑜伽中', '短托腹裤', '孕产妇运动', '孕妇分体泳衣',
        '孕妇瑜伽长托腹裤', '孕妇连体泳衣', '孕妇瑜伽背心', '孕妇瑜伽套装', '孕妇瑜伽文胸', '产后塑形仪', '孕产修复仪',
        '乳房按摩恢复仪', '骨盆按摩器', '祛妊娠纹按摩仪', '盆底肌修复仪', '孕妇铅笔裤', '孕妇裤', '托腹裤',
        '孕妇喇叭裤', '孕妇打底裤', '孕妇直筒裤', '孕妇灯笼裤', '孕妇背带裤', '孕妇阔腿裤', '月子营养', '月乃汤',
        '通乳产品', '月子米酒', '月子餐', '月子食用油', '孕产妇彩妆套装', '孕产妇彩妆', '孕产妇眉笔', '孕产妇bb霜',
        '孕产妇腮红', '孕产妇唇膏', '睫毛增长液', '孕产妇卸妆', '辅食盒', '辅食袋', '辅食碗', '餐具', '研磨',
        '辅食小家电', '儿童保温杯', '宝宝蒸蛋机', '煮蛋器', '儿童牛奶杯', '果汁杯', '食物研磨器', '水杯配件', 'BB煲',
        '电粥锅', '儿童餐具', '婴童餐椅', '儿童饭盒', '摇奶器', '魔术杯软嘴', '其它喂哺用品', '吸管', '宝宝辅食料理机',
        '绞肉器', '儿童餐垫', '喂养勺', '训练勺', '辅食勺', '硅胶勺', '吸管刷', '儿童训练筷', '练习筷',
        '婴童洗浴护肤礼盒', '宝宝护肤', '宝宝紫草膏', '舒缓膏', '防晒棒', '宝宝护肤体验装', '痱子粉', '爽身水',
        '儿童淡疤护理（非药械）', '儿童乳液', '儿童保湿喷雾', '儿童香水', '护臀膏', '按摩油', '儿童精华水', '宝宝护手霜',
        '润肤乳', '宝宝护唇', '润唇', '儿童洗面奶', '儿童指甲油', '儿童面膜', '婴儿湿巾', '牙胶', '儿童口腔喷雾',
        '宝宝舌苔刷', '洁舌器', '儿童牙线', '牙膏牙刷套装', '乳牙刷', '训练牙刷', '护齿牙刷', '宝宝刷牙杯', '固齿器',
        '宝宝漱口水', '婴童牙膏', '辅食咬咬袋', '果汁咬咬袋', '辅食喂养器', '电动牙刷', '儿童护牙素', '被子',
        '儿童床品', '婴童', '儿童四件套', '婴童枕头', '枕芯', '婴童床单', '婴童被套', '毯子', '婴童蚊帐', '抱被',
        '婴童凉席', '婴童多件套', '婴童睡袋', '防踢被', '儿童三件套', '背袋', '学步带', '出行用品', '雨伞', '抱婴腰带',
        '腰凳', '婴童防护口罩', '儿童牵引绳', '育儿背巾', '婴童防护耳罩', '儿童马桶架', '宝宝如厕用品', '宝宝洗头椅',
        '儿童马桶盖', '儿童坐便凳', '单杆轻便推车', '婴儿手推车', '学步车', '三轮推车', '推车棉垫', '推车配件',
        '推车雨罩', '四轮推车', '双胞胎推车', '婴儿棉柔巾', '床单', '凉席', '床品', '婴童床品套件', '儿童床笠', '床罩',
        '婴童床垫', '睡袋礼盒', '儿童枕套', '床褥', '婴童凉席系列', '婴童毛毯', '盖毯', '婴童抱被', '抱毯', '床围',
        '床靠', '尿布袋', '床头挂袋', '调奶器', '消毒', '暖奶', '喂养小家电', '暖奶器', '加热器', '消毒包',
        '奶瓶消毒器', '消毒锅', '电动奶粉搅拌器', '宝宝洗衣液', '宝宝清洁液', '柔顺剂', '奶瓶果蔬清洗液', '尿布皂',
        '儿童内衣裤清洗液', '宝宝清洁洗护套装', '宝宝免洗手消毒喷雾', '母婴清洁泡泡盐', '宝宝洗衣凝珠',
        '婴童鼻眼清洗液', '宝宝洗衣粉', '婴儿衣服消毒柜', '宝宝洗手液', '便携洗手液', '洗手皂片', '宝宝衣物消毒液',
        '衣物柔顺', '柔软剂', '宝宝除螨喷雾', '除螨贴', '驱蚊用品', '宝宝防蚊水', '宝宝驱蚊手带', '宝宝蚊香片',
        '宝宝驱蚊贴', '宝宝贴', '宝宝驱蚊香薰', '宝宝驱蚊器', '宝宝止痒膏', '止痒走珠', '驱蚊止痒二合一', '宝宝蚊香液',
        '宝宝防蚊湿巾', '宝宝金水', '床中床', '童床', '婴儿床', '摇篮', '床护栏', '摇椅', '背包床', '幼儿园专用床',
        '蹬被', '尿湿', '防丢提醒器', '儿童床', '安全别针', '防撞', '安全', '防摔帽', '防触电保护', '保护盖', '保护罩',
        '婴儿监护器', '安全门卡', '多功能安全锁', '门护栏', '防撞条', '防撞角', '儿童踏脚凳', '儿童房', '桌椅', '家具',
        '成套桌椅', '儿童桌', '沙发', '儿童储物架', '收纳架', '婴儿房', '婴童衣架', '儿童书桌椅', '写字台', '儿童椅',
        '玩具椅', '其它婴童用品', '婴童用品提货', '奶嘴', '安抚奶嘴', '奶嘴相关', '奶嘴储存盒', '奶嘴盒', '奶嘴链',
        '奶嘴打孔器', '儿童座椅', '电动车儿童座椅', '儿童座椅棚', '保温奶瓶', '奶瓶', '奶瓶相关', '防胀气装置',
        '智能奶瓶', '奶瓶夹', '奶瓶温度计', '奶瓶把', '手柄', '奶瓶储存盒', '奶瓶盒', '奶瓶刷', '奶嘴刷', '奶粉储存盒',
        '奶粉盒', '保温桶', '保温包袋', '保温箱', '奶瓶盖', '奶瓶干燥架', '母婴用纸', '汽车座椅', '汽车安全座椅',
        '安全背带', '汽车背带', '宝宝浴盆', '宝宝洗浴', '洗发帽', '水温计', '宝宝脸盆', '浴巾', '儿童泡浴包', '婴儿皂',
        '儿童皂', '浴网', '浴兜', '沐浴棉', '洗发杯', '水勺', '沐浴乳', '婴童护发素', '儿童洗漱台', '婴童洗发水',
        '儿童洗手机器', '宝宝量温', '理发', '指甲钳等护理小用品', '宝宝剪刀', '喂药器', '儿童套袖', '一次性套袖',
        '抱娃吸汗套袖', '吸鼻器', '理发清洁', '护理套装', '尿布桶配件', '儿童眼罩', '宝宝耳勺', '发光耳勺',
        '婴儿电子秤', '温湿度计', '室温计', '安全梳子', '刷子', '宝宝棉棒', '宝宝电动磨甲器', '婴儿电吹风', '理发围布',
        '湿巾加热器', '清洁镊子', '儿童引水器', '儿童睡眠贴', '宝宝理发器', '尿布桶', '身高尺', '婴幼儿牛奶粉（2段）',
        '婴幼儿液态奶', '婴幼儿营养奶昔', '婴童营养品', '钙铁锌', '婴幼儿营养包', '清凉', '调理', '奶伴', '蛋白粉',
        '婴幼儿凝胶糖果', '鱼肝油', '葡萄糖', '婴幼儿乳钙', '益生菌', '牛初乳', '乳铁蛋白', '婴幼儿牛脾肽', '维生素',
        '婴幼儿秋梨膏', '奶粉提货', '宝宝咖喱', '婴童调味品', '调料', '婴幼儿羊奶粉（1段）', '婴幼儿牛奶粉（1段）',
        '儿童奶粉', '婴幼儿牛奶粉（3段）', '婴幼儿羊奶粉（3段）', '溶溶豆', '婴童零食', '肉肠', '泡芙', '宝宝奶酪',
        '宝宝奶片', '果肉条', '海苔', '宝宝辅食提货', '宝宝辅食', '宝宝猪肝粉', '磨牙棒', '宝宝馒头', '果汁', '饮品',
        '宝宝的芝麻粉', '胚芽米', '米粉', '米糊', '汤粥', '宝宝虾皮粉', '菜粉', '水果粉', '肉松', '鱼松', '宝宝水饺',
        '馄饨', '混合泥', '特殊医学用途婴儿配方食品', '特殊配方奶粉', '低体重儿', '早产儿奶粉', '防腹泻', '抗过敏奶粉',
        '婴幼儿羊奶粉（2段）', '尿布台', '尿裤周边', '拉拉裤', '纸尿片', '医护级尿裤', '特护尿裤', '早产儿尿裤',
        '婴儿游泳纸尿裤', '隔尿垫巾', '布尿裤', '尿垫', '一次性小内裤', '尿布带', '隔尿裙', '纱布尿布', '隔尿床垫',
        '纸尿裤', '妙鲜包', '猫零食（新）', '猫零食', '猫罐头', '兔绳', '兔类及其用品', '草架', '兔兔干草', '饮水器',
        '服饰', '厕所', '脚垫', '垫料', '兔兔主粮', '食盆', '笼子', '兔兔零食', '兔兔磨牙', '宠物相册、明信片等周边',
        '宠物附属品（新）', '标本', '宠物车贴', '宠物殡葬用品', '犬主粮', '狗医疗用品（非药品）', '体温计', '手术台',
        '绷带', '试纸', '狗通用食品', '宠物指甲套', '宠物服饰及配件', '鞋子', '头饰', '宠物背包', '其它服饰配件',
        '宠物服装', '挂饰', '挂牌', '畜牧饲料', '畜牧用品（新）', '畜牧器械', '猫主粮', '鸟类及用品', '鸟笼', '笼衣',
        '鸟食', '飞鼠', '仓鼠类及其它小宠', '龙猫', '宠物貂', '豚鼠', '宠物狐狸', '香猪', '仓鼠', '其它宠物',
        '其它宠物粮食', '其它宠物用具', '宠物托运', '宠物生活服务', '其他宠物服务', '宠物摄影', '宠物清洁', '宠物训练',
        '宠物美容', '宠物寄养', '宠物配种', '宠物医疗', '宠物殡葬', '猫奶粉', '狗保健品', '狗奶粉', '蝎类', '爬虫',
        '鸣虫及其用品', '蜘蛛', '蚂蚁工坊', '蚕宝宝', '鸣虫食物', '鸣虫用具', '蟋蟀', '其他爬虫', '鸣虫', '航空箱',
        '狗日用品', '宠物车载笼', '杯子', '嘴套', '散热板', '家用牵引带', '宠物汽车安全带', '储粮桶', '项圈', '背包',
        '自动喂食器', '止吠器', '宠物安全扣', '宠物垫', '专业比赛牵引带', '宠物车载垫', '训练器', '更多日用品',
        '诱导剂', '追踪器', '水头', '宠物推车', '语言翻译机', '电热板', '电热毯', '宠物智能监控伴侣设备',
        '宠物智能设备', '宠物智能环境监察设备', '宠物智能穿戴设备', '宠物智能喂养设备', '散装猫主粮', '散装粮',
        '散装犬主粮', '马蹄挫', '马类及其用品', '马饲料', '马鞍', '马笼套', '马口衔', '马嚼子', '马刺',
        '观赏虾蟹等饲料', '水族世界', '水族服务', '黑水素', '鱼缸净水剂', '观赏龟', '鳖饲料', '其它水族宠物', '除藻剂',
        '鱼缸水质稳定剂', '其他益生菌', '硝化细菌', 'PH调节剂', '观赏鱼饲料', '畜牧药品', '动物药品及药剂', '宠物驱虫',
        '水族药品药剂', '狗药品', '飞盘', '狗玩具', '猫抓板', '漏食球', '橡胶球', '球形玩具', '发声玩具', '丝瓜络玩具',
        '套装玩具', '猫爬架', '绳结玩具', '逗猫棒', '其它玩具', '狗零食', '浴池', '浴盆', '狗美容清洁用品', '电推剪',
        '狗厕所', '吹水机', '美容服', '美容剪', '排梳', '猫砂铲', '脚掌滋润', '防滑', '除味剂', '尿片', '眼部清洁',
        '美容台', '口腔清洁', '拾便器', '猫砂', '吸水毛巾', '牙具', '吹风机', '指甲剪', '香波浴液', '猫砂盆', '猫厕所',
        '其他美容清洁用品', '耳部清洁', '洗澡', '按摩刷', '粘毛器', '针梳', '儿童机器人', '变形玩具', '变形',
        '人偶玩具', '其他人偶玩具', '奥特曼玩具专区', '坦克', '油动电动模型', '直升机', '固定翼', '船模', '车模',
        '不倒翁', '幼儿响铃', '布玩', '安抚玩具', '宝宝布书', '布质', '软胶积木', '拨浪鼓', '床铃', '床挂', '摇铃',
        '手偶', '安抚玩偶', '架子鼓', '音乐玩具', '儿童乐器', '玩具钢琴', '沙锤', '沙蛋', '沙球', '电动手拍鼓',
        '音乐电话', '音乐话筒', '电子琴玩具', '儿童电子琴', '其他音乐玩具', '玩具吉他', '打击乐器', '吹奏玩具',
        '玩具小提琴', '手风琴', '铃类乐器', '八音盒', '音乐盒', '敲琴', '乐器套装', '电动', '遥控机器人', '遥控',
        '惯性', '发条玩具', '遥控动物', '垂直悬浮玩具', '遥控车', '遥控船类', '遥控轨道', '回力', '滑行玩具',
        '遥控飞机', '儿童包', '行李箱', '储物箱', '拉杆箱', '编程玩具', '儿童智能玩具', 'app互动玩具', '意念控制玩具',
        '颜料', '绘画类用品', '画板', '调色盘', '绘画桌', '画布', '画笔', '画刷', '颜料绘画组合', '智能娃娃', '娃娃',
        '宝宝纪念品', '个性产品', '胎毛挂坠', '名字贴', '胎毛绣', '胎毛笔', '纪念册', '宝宝饰品套装', '长命锁',
        '手脚印', '脚镯', '胎毛章', '过家家玩具', '仿真', '食物', '仿真照相机', '动物玩偶', '儿童化妆玩具',
        '其它仿真玩具', '切切看', '爬行垫', '幼儿爬行', '学步', '手推学步玩具', '婴儿健身器', '游戏毯', '音乐毯',
        '拖拉学步玩具', '幼儿学爬玩具', '塑料充气玩具（其他材质勿放）', '发光', '充气', '整蛊玩具', '创意', '发光玩具',
        '电子玩具', '科普百科', '儿童读物', '童书', '益智游戏', '绘本', '图画书', '启蒙', '认知', '少儿英语',
        '其它儿童读物', '儿童文学', '少儿艺术', '飞碟', '竹蜻蜓类', '户外运动', '传统玩具', '跳跳玩具', '跳跃类运动',
        '拳击袋', '拳击手套', '射击', '射箭类', '投掷套圈', '吹泡泡', '其他户外休闲玩具', '风车', '儿童帐篷', '游戏屋',
        '摇马', '球类玩具', '球类运动', '海洋球', '波波球', '儿童轮滑', '护具', '儿童滑板车', '踏行车', '滑行学步车',
        '扭扭车', '溜冰鞋', '旱冰鞋', '儿童电动车', '童车配件', '手工串珠', '穿珠', '首饰编织', '手工制作', '创意DIY',
        '沙画', '胶画', 'DIY玉米粒', '手工制作工具', '彩纸', '其他手工制作', '白模填色', '模具彩绘', '手工折纸',
        '剪纸书', '织布机', '手工编织', '刺绣类', '手工食品制作', '手工创意粘贴类', '船舶', '舰艇', '静态模型',
        '火车模型', '军舰', '航母', '关节木偶', '其他模型玩具', '飞机模型', '军事战车', '家居', '生活场景', '建筑',
        'DIY小屋', '拼装模型', '积木桌', '迷宫类', '解锁', '迷宫', '智力玩具', '解环玩具', '智力解题', '通关玩具',
        '玩具挂图', '认知卡', '智能玩具', '早教机', '点读学习', '其它早教玩具类', '早教闪卡', '潜能开发卡',
        '儿童玩具表', '多功能玩具台', '游戏桌', '智能公仔', '宝宝海报', '胎教海报', '儿童MP3', '故事机', '早教教具',
        '早教套装', '磁性贴', '充气筒', '儿童耳塞', '护耳贴', '戏水', '玩沙玩具', '儿童泳镜', '儿童救生衣', '溶质',
        '护脐贴', '儿童鼻夹', '洗澡书', '水上游艺设施', '婴儿', '儿童游泳圈', '遥控飞机零配件', '电动遥控玩具零件',
        '遥控车升级件', '四驱车零配件', '育儿百科', '育儿书籍', '育儿其他', '家庭教育', '孕产', '育儿', '儿童书法用品',
        '实验', '绘画文具', '笔筒', '文具礼盒', '绘画套装', '科学实验', '坐姿矫正器', '描红本', '涂色本', '橡皮',
        '数学学习板', '计算架', '笔类', '削笔器', '削笔刀', '文件袋', '笔袋', '文具盒', '其他文具', '儿童桌面游戏类',
        '儿童棋类', '桌面游戏', '强手棋', '大富翁棋', '游戏叠叠乐', '多功能棋', '彩泥', '橡皮泥', '粘土', '软陶泥',
        '太空沙', '魔力沙', '动力沙', '星空沙', '超轻粘土', '毛绒布艺类玩具', '游乐', '教学设备', '大型设施', '跷跷板',
        '滑梯', '儿童台球桌', '儿童玩具墙贴', '游戏围栏', '其他游乐设施', '软体组合器材', '碰碰车', '游艺机',
        '大型组合式游乐设备', '蹦床', '感统训练器材', '麻将机', '摇摆机', '摇摇乐', '乐吧车', '隧道', '钻洞', '插珠',
        '蘑菇插钉', '串珠', '拼图', '配对', '拆装', '敲打玩具', '螺母拆装', '组合玩具', '敲打台', '其他敲打玩具',
        '建构', '拼插积木', '磁力棒', '拼板', '婴幼儿串珠', '绕珠', '叠叠圈', '叠套玩具', '数字屋', '形状盒',
        '多孔认知玩具', '打地鼠', '敲击果虫', '婴儿手抓球', '其他形状认知', '配对玩具', '螺丝形状配对玩具',
        '几何形状套柱', '钓鱼类玩具', '形状配对扭扭蛋', '其他玩具枪', '儿童玩具枪', '水枪', '电动玩具枪', '水弹枪',
        '软弹枪', '悠悠(溜溜)球', '体育周边', '棉花娃娃', '毛绒玩具娃衣', '娃衣', '潮玩娃衣', 'OB娃衣', '模型娃衣',
        'BJD娃衣', '兵人娃衣', '动漫游戏展', '演出票', '游戏实物周边', '二次元和服', '棋牌桌', '桌游卡牌', '桌游配件',
        '剧本杀剧本', '道具', '四子棋', '五子棋', '其它棋牌', '洛丽塔裤子', '二次元lolita', '洛丽塔袜子', '洛丽塔配饰',
        '洛丽塔包袋', '洛丽塔假发', '洛丽塔鞋类', '洛丽塔半身裙', '洛丽塔短外套', '洛丽塔连衣裙', '洛丽塔', '软妹装',
        '洋装', '动漫游戏纸模', '纸模', '纸质模型', '机甲', '高达纸模', '其他类型纸模', 'lolita洛丽塔大衣', 'lolita',
        '童装lolita洛丽塔', '手办景品', '兵人', '扭蛋', '海贼王手办专区', '兵人专区', '盒蛋', '食玩', '其他拼装',
        '组装模型', '高达', '机甲模型', '机器人', '变形类', '太空堡垒模型专区', '变形金刚模型专区',
        '圣斗士星矢模型专区', '新世纪福音战士机体专区', '机甲成品', '变形系列', '高达模型专区', '建筑模型', '车船模',
        '军模', '无人机', '穿越机', '其他模型', '船只', '舰船模型', '航模', '儿童无人机', '摩托', '汽车模型', '战车',
        '武器模型', '模型制作工具', '辅料耗材', 'BJD场景道具娃屋', '潮玩场景道具', '盲盒场景道具娃屋', '明星周边',
        'BJD娃娃', '古风中衣', '二次元古风服装', '古风套装', '古风外衣', '古风配饰', '古风内衣', '收藏卡牌', '卡片',
        '学生装cos', 'Cosplay服饰', 'Cosplay男装', 'Cosplay女装', 'COSPLAY配件', '人偶服', 'cos摄影', '后期',
        '动漫3C周边', '数码电器', '卡通', '动漫周边', '动漫水杯', '百货', '动漫T恤', '鞋帽', '服装', '动漫电子', '本子',
        '动漫卡牌', '文具', '动漫周边配饰', '动漫毛绒', '抱枕', '动漫背包', '预售模玩', '假面骑士专区', '特摄周边',
        '综合特摄专区', '聚会', '魔术', '演出用品', '潮玩盲盒', '音笛', '乐器配件', '电源', '适配器', '鼓棒', '鼓锤',
        '鼓槌', '胶带', '音叉', '踏板', '哨片', '琴凳', '键盘凳', '乐器连接线', '乐器指甲', '琴弦', '键盘架', '踏套',
        '哑鼓垫', '拨片', '调音器', '乐器罩', '节拍器', '其他支架', '踏板控制器', '号嘴', '松香等低值易耗品', '鼓凳',
        '谱架', '谱台', '乐器盒', '鼓架', '镲架', '指挥棒', '镲片', '笛头', '乐器包', '擦拭布', '抛光布', '鼓皮',
        '鼓刷', '笛膜', '其它乐器配件', '手指练习器', '电子合成器', '乐器定制', '乐器服务', '乐器考级', '乐器教学',
        '乐器维修', '乐器工具', '乐器周边', '五线谱电教板', '乐器软件', 'MIDI乐器', '录音棚监听控制器', '话筒夹',
        '话筒架', '电子吹管', '模拟合成器', '软音源', '混音器', '调音台', 'MIDI键盘控制器', 'MIDI键盘', '话筒',
        '编曲键盘', '声卡接口', '音频接口', '耳机放大器', 'MIDI吹奏控制器', '话筒放大器', '其它MIDI配件', '声卡转换器',
        '儿童吉他', '儿童玩具乐器', '儿童钢琴', '儿童口琴', '儿童口风琴', '儿童击打乐器', '儿童摇铃', '儿童架子鼓',
        '监听音箱', '乐器音箱', '监听耳机', '键盘音箱', '音箱脚踏控制器', '音箱其他', '音箱支架', '吉他音箱',
        '箱琴音箱', '多功能音箱', '贝司音箱', '西洋吹奏乐器', '西洋乐器', '西洋吹打击器', '减肥塑身', '娱乐时尚',
        '美体', '时尚图鉴', '星座', '占卜', '明星写真', '皮肤病学', '性病学', '医学卫生', '内科学', '医学图谱',
        '肿瘤学', '基础医学', '中医', '妇产科学', '医学其它', '中西医结合', '医院管理', '老年病学', '预防医学、卫生学',
        '麻醉学', '全科医学', '口腔科学', '影像医学', '神经病和精神病学', '临床医学', '医疗器械及使用', '药学',
        '特种医学', '耳鼻喉科学', '护理学', '儿科学', '外科学', '急救急诊', '眼科学', '党政读物', '政治军事',
        '政治军事其它', '世界军事', '军事理论', '政治理论', '领袖著作', '公共管理', '世界政治', '中外战争纪实', '时政',
        '中国政治', '军事技术', '中国军事', '世界各国共产党', '共产主义运动', '兵器', '外交', '国际关系',
        '艺术体育考试', '教材', '教辅', '论文', '考研', '社会实用教材', '自由组套（仅限弱关联套装书）',
        '高职高专教材教辅', '司法考试', '论文集', '高等成人教育', '公务员考试', '幼儿早教', '启蒙认知书', '黑白卡',
        '识字卡', '少儿动漫书', '立体翻翻书', '玩具书', '手工贴纸书', '涂色书', '商务谈判', '管理', '项目管理',
        '领导学', '企业管理', '人力资源', '管理其它', '生产与运作管理', '电子商务', '金融投资', '广告营销',
        '创业企业和企业家', '管理学理论', '商业史传', '财务管理', '商务写作', '企业经营与管理', '供应链管理',
        '战略管理', '科学学', '科学', '科学研究', '专利研究', '技术标准研究', '情报学', '情报工作', '科学研究方法论',
        '世界各国科学研究事业', '知识学', '科学发明研究', '创造学', '科学研究组织', '工作方法', '未来学', '职场',
        '自我实现', '励志', '演讲', '口才', '人际沟通', '礼仪', '心灵与修养', '面试', '谋略', '时间管理', '情商与情绪',
        '考试类原版书', '进口原版书(含港台)', '艺术类原版书', '管理类原版书', '文化类原版书', '漫画类原版书',
        '工具书原版书', '小说类原版书', '科学技术类原版书', '经济类原版书', '生活类原版书', '原版其它', '健康类原版书',
        '文学类原版书', '人文社科类原版书', '儿童读物原版书', '科普读物原版书', '社会科学类原版书', '自然科学类原版书',
        '法律类原版书', '旅游类原版书', '娱乐时尚类原版书', '国外旅游指南', '旅游随笔', '特色旅游', '旅游其它',
        '国内旅游指南', '导游专业用书', '旅游理论与实务', '旅游小百科', '旅游摄影', '画册', '财经报纸期刊',
        '期刊报纸现刊', '单刊', '过刊', '烹饪', '饮食报纸期刊', '两性报纸期刊', '旅游报纸期刊', '美容报纸期刊',
        '医疗保健报纸期刊', '宠物报纸期刊', '体育运动报纸期刊', '时尚报纸期刊', '艺术', '摄影报纸期刊', '汽车报纸期刊',
        '计算机报纸期刊', '养生食疗', '时事报纸期刊', '人文地理报纸期刊', '家居设计报纸期刊', '综合及其它报纸期刊',
        '育儿报纸期刊', '文摘', '文学报纸期刊', '音乐报纸期刊', '地球物理学', '自然科学', '物理学', '自然科学史',
        '研究方法', '测绘学', '其它科学技术', '晶体学', '生物学', '海洋学', '气象学', '天文学', '生命科学', '地质学',
        '化学', '自然科学总论', '地理学', '自然地理学', '航空与航天', '爱车一族书籍', '家居风水类书籍', '菜谱',
        '炒股书籍', '都市手工艺书籍', '幽默笑话书籍', '理财', '基金书籍', '饮食文化书籍', '婚恋', '购房', '置业书籍',
        '博彩类书籍', '生活百科书籍', '其它生活书籍', '家居装修书籍', '养花书籍', '茶类书籍', '青春', '都市', '言情',
        '影视同期书', '宫廷', '现代小说1919-1949年', '军事小说', '职场小说', '近代小说（1919年前）', '武侠小说',
        '惊悚小说', '世界名著', '乡土小说', '穿越', '重生', '架空', '科幻小说', '侦探推理', '官场小说', '外国小说',
        '其它小说', '玄幻', '短篇小说集', '故事集', '文化理论', '信息与知识传播', '信息与传播理论', '世界文化',
        '中国民俗', '文化评述', '图书馆学 档案学', '中国文化', '文化其它', '神秘现象', '广播', '电视事业',
        '地域文化 群众文化', '程序设计', '计算机', '网络', '计算机软件工程', '计算机系统结构', '计算机安全与密码学',
        '图形图像', '多媒体', '软件工程', '操作系统', '其它计算机', '网络书籍', '计算机手册', '数据库',
        '计算机硬件组装、维护', '安全与加密', '办公自动化软件', '网站设计', '网页设计语言', '网络通信',
        '计算机控制仿真与人工智能', '信息系统', '计算机系统结构其它', '计算机辅助设计和工程', '计算机理论和方法',
        '政治', '残损库存品', '外观瑕疵品', '考试教材', '期刊杂志', '医学', '儿童书', '工具书', '经济', '育儿书',
        '社会科学', '哲学宗教', '外语', '语言文字', '在线学习卡', '文学', '地理', '文化创意笔记本', '图书周边', '文体',
        '工艺品', '文化创意书签', '文化创意胶带', '其他图书周边', '文化创意环保袋', '作家手作', '原稿', '文化创意手账',
        '图书点读套装', '文化创意明信片', '文化创意台历', '两性关系', '婚恋与两性', '性知识', '体育运动', '旅游地图册',
        '世界行政区划图', '交通地图', '中国行政区划图', '地区概况', '税务理论', '实用税务', '区域经济', '经济史',
        '贸易政策', '世界及各国经济概况', '通货膨胀', '国际贸易', '世界各国贸易', '商品学', '金融', '财政', '货币',
        '税收', '经济理论', '统计 审计', '国民经济管理', '保险业', '中国经济', '中国经济史', '国内贸易经济', '会计',
        '各部门经济', '经济计划', '经济计算及方法', '经济其它', '自由组合套装', '报纸现刊', '百科全书', '色卡',
        '专业辞典', '年鉴', '年刊', '其它工具书', '汉语', '辞典', '图书目录文摘索引', '能源与动力工程', '工业',
        '农业技术', '电工技术', '家电维修', '石油 天然气工业', '自动化技术', '化学工业', '机械工程', '环境科学',
        '原子能技术', '冶金工业', '轻工业', '手工业', '汽车', '航空航天', '家用电器', '工业技术其它', '水利',
        '电子电路', '通信', '交通', '运输', '电信通信', '矿业技术', '领袖', '传记', '普通百姓', '教育家', '文学家',
        '艺术家', '建筑设计', '传记其它', '影星', '歌星', '体育界', '医学家', '综合', '科学家', '哲学家',
        '历史知识读物', '史学理论', '地方史志', '民族史志', '文物', '考古', '古籍', '心理健康', '心理类书籍',
        '常见病防治', '中老年保健', '两性健康', '中医养生', '饮食营养 食疗', '家庭医生', '宗教理论', '哲学和宗教',
        '基督教', '哲学总论', '哲学知识读物', '哲学其它', '伊斯兰教', '中国哲学', '其他宗教', '马克思主义哲学', '美学',
        '佛教', '道教', '天主教', '犹太教', '逻辑学', '外国哲学', '伦理学', '宗教知识读物', '文学其它', '中国近代随笔',
        '中国现当代诗歌', '文学作品集', '文学理论', '文学评论与研究', '纪实', '报告文学', '外国诗歌', '回忆录',
        '文学史', '中国古代随笔', '戏剧', '民间文学', '民族文学', '中国古诗词', '外国随笔', '散文集', '现代',
        '当代文学', '儿童营养健康', '胎教', '健身与保健', '篆刻', '字帖书籍', '电视艺术', '艺术理论', '设计',
        '艺术其它', '收藏鉴赏', '工艺美术', '建筑艺术', '民间艺术', '雕塑', '人体艺术', '摄影艺术', '中国少数民族语言',
        '汉藏语系', '漫画书籍', '漫画集', '传媒出版', '文化人类学', '中国社会', '外国社会', '民族学', '劳动科学',
        '社会科学其它', '统计学', '社会学', '系统论', '系统科学', '系统工程', '心理学', '社会科学总论', '教育',
        '教育普及', '字帖', '练字帖', '练字板', '毛笔字贴', '亲子', '知识服务', '读书卡', '学术探索', '升学', '财经类',
        '语言', '留学', '其他服务', '兴趣', '影音传媒', '科学科普', '犯罪学', '刑事侦查学', '宪法', '诉讼法', '财政法',
        '经济法', '司法鉴定', '法医学', '法律文书写作', '土地法', '农业经济管理法令', '法学理论',
        '自然资源与环境保护法', '劳动与社会保障法', '刑法', '民法', '港澳台地区', '特别行政区基本法', '行政法',
        '司法制度', '高等法律教材', '商法', '法律知识读物', '司法案例', '实务解析', '世界各国法律', '法律汇编',
        '法律法规', '国际法', '护眼灯', '教学演示', '展示告示用品', '黑板', '荧光板', '计划表', '绿板', '粉笔',
        '教学标本', '白板笔', '教学仪器', '实验器材', '激光笔', '教鞭', '展板', '红领巾', '地球仪', '旗帜', '标志牌',
        '提示牌', '白板', '软木板', '照片板', '毛毡板', '丙烯颜料', '画具', '画材', '书法用品', '调色纸',
        '万年红对联纸', '工笔填色套装', '油画布', '智能取色笔', '水彩纸', '水彩水粉颜料本', '宣纸', '揉擦笔', '揉擦绵',
        '毛笔字帖', '色彩风干器', '速干器', '油画专用笔', '水彩颜料', '笔帘', '文房四宝', '墨块', '墨丸', '画架',
        '笔挂', '国画颜料', '毛笔', '勾线笔', '颜料分装盒', '调色盒', '油画刀', '蜡笔', '毛边纸', '铅画纸', '笔洗',
        '儿童填色本', '写生车', '多功能画车', '绘图', '白图纸', '画袋', '调色板', '电动喷绘笔', '文房墨汁', '油画框',
        '拷贝台', '临摹台', '油画颜料', '镇纸', '石膏像', '描图', '硫酸纸', '素写本', '水写布', '书画毛毡垫', '油画棒',
        '水彩笔', '水粉颜料', '书法绘画学习套装', '书法用纸', '软头笔', '书立', '阅读架', '学习收纳', '陈列用品',
        '档案盒', '文件夹', '资料册', '文件架', '握笔器', '成品印章', '儿童印章', '文具套装', '书写工具', '可爱印泥',
        '修正液', '装订文具', '写字护指绷带', '书皮', '修正带', '视力保护器', '压花器', '补习袋', '修正贴',
        '桌面清洁器', '学生书包', '胶带切割器', '折纸', '手工纸', '卷笔刀', '系统软件', '软件', '办公软件', '程序',
        '网站开发', '财务软件', '电脑入门培训', '认证考试', '建筑软件', '水产养殖', '农业生产', '花卉栽培', '家禽养殖',
        '水果种植', '蔬菜种植', '畜牧养殖', '粮食作物种植', '语言识字', '亲子幼教', '拼音学习', '国学启蒙', '智力启蒙',
        '婴幼儿教育', '童话故事', '书法绘画', '歌谣', '父母学堂', '财务', '考级', '播音主持', '恋爱养成', '网络游戏',
        '体育竞技', '益智休闲', '策略游戏', '角色扮演', '冒险', '游戏小说', '游戏周边', '即时战略', '射击游戏',
        '赛车游戏', '模拟经营', '韩语', '朝鲜语', '小语种', '汉语学习', '意大利语', '俄语', '法语', '西班牙语',
        '音乐影视音像', '音乐CD', '黑胶唱片', 'u盘', '生活百科', '成人教育音像', '戏曲综艺', '儿童教育音像', '职业英语',
        '商务英语', '英语学习', '词汇', '听力', '高中英语', '写作', '生活英语', '英语考试', '音标', '口语',
        '影视原声学英语', '家政物业', '职业教育', '机械加工', '酒店餐饮', '维修维护', '建筑施工', '驾驶培训', '经管',
        '培训', '行业培训', '市场营销管理', '职业素养', '个人修炼', '生产管理', '职业经理人', '领导力', '国学',
        '党政学习', '运营管理', '商务社交礼仪', '销售管理', '行政管理', '融资', '名家访谈', '讲座', '模型组装',
        '周边产品', '早教益智', '拼插', '青少年心理健康', '自考', '中考', '医学教材', '社科', '自出版电子书',
        '古典（1911年前）', '学习考试类', '当代文学小说', '出版物电子书', '动漫小说', '灯笼', '节日用品', '贺卡', '花灯',
        '圣诞鹿', '节日装饰品', '福字', '圣诞树', '圣诞服饰', '电子鞭炮', '生肖用品', '门幅', '门神', '对联',
        '角色扮演类用品', '节庆礼盒', '圣诞帽', '圣诞礼品', '圣诞袜', '文化创意扇', '文化创意用品', '文化创意餐具',
        '文化创意信封', '文化创意灯', '文化创意包', '文化创意文具', '文创礼盒', '文化创意冰箱贴', '文化创意杯垫',
        '餐垫', '文化创意地垫', '文化创意化妆镜', '文化创意铃铛', '文化创意装饰画', '文化创意邮册', '出版物',
        '文化创意镜子', '文化创意杯子', '文化创意毯子', '文化创意加湿器', '文化创意抱枕', '文化创意手绳', '手环',
        '文化创意御守', '文化创意瓶', '文化创意钱包', '购物收纳袋', '文化衫', '功能机', '合约机', '智能机',
        '智能机器人', 'XR设备', '智能语音转译设备', '智能摄像', '云台', '监控摄像头', '智能平衡车', '智能翻译机',
        '智能清洁', '智能设备配件', '智能监护', '智能教育', '智能健康', '智能出行', '智能音箱', '智能支付终端',
        '飞行器配件', '智能飞行', '飞行器整件', '智能耳机', '其他智能物联', '智能健身', 'AI语音助手', '智能物联',
        '智能儿童手表', '智能配饰', '智能手表', '其他智能设备', '智能穿戴', '运动跟踪器', '轻薄笔记本', '折叠屏笔记本',
        '设计师电脑', '迷你笔记本电脑', '云电脑', '游戏笔记本', '二合一笔记本', 'DIY一体机', 'DIY笔记本', 'DIY兼容机',
        '智慧白板', 'Server', '台式整机', '直播一体机', '工作站', '一体机', '广告机', '智慧屏', '主板', '虚拟现实设备',
        '绘图板配件', '连接线', '连接器', '转换器', '理线带', '理线器', 'UPS电源', '鼠标垫', '腕垫', 'CRT显示器',
        '光盘盒', 'CD包', '图文信息', '采集卡', '无线电脑周边产品', '硬盘盒', '耳麦', 'CMMB终端', '其它电脑周边',
        '保护屏', '防尘罩', '软驱', '光驱', '刻录', '键帽', '企业级电源', '企业级配件', '企业级显示器', '企业级显卡',
        '企业级硬盘', '企业级主板', '企业级内存', '企业级机箱', '机械硬盘', '散热器', '风扇', '手写输入', '绘图板',
        '智能电脑硬件', '内存', '显卡', '机箱', 'K歌', '直播声卡套装', 'CPU主板套装', '电脑视听配件', '有线鼠标',
        '声卡', '键鼠套装', '机箱电源风扇套装', '无线鼠标', '键盘', '显示器校色仪', '显示器&支架', '组装液晶显示器',
        '便携显示器', '拼接屏', '显示器配件', '固态硬盘', '数码相机', '运动相机', '专业数码', '全景相机', '微单相机',
        '数码摄像机', '胶卷相机', '拍立得相机', '单反相机', '客厅冰箱', '冰箱', '冰吧', '冰柜', '冷柜', '便携冷热箱',
        '化妆品冰箱', '雪茄柜', '厨房冰箱', '嵌入式冰箱', '茶几冰箱', '母婴冰箱', '壁挂洗衣机', '洗衣机', '折叠洗衣机',
        '滚筒洗衣机', '空气源热泵热水器', '热水器', '热厨套装', '燃气热水器', '即热式热水器', '太阳能热水器',
        '电热水器', '电热水龙头', '厨宝', '空调配件', '大家电配件', '电视机配件', '洗衣机配件', '便携冷热箱配件',
        '其他大家电配件', '冰箱配件', '烟机灶具配件', '激光电视', '电视', '商用电视', '平板电视', '洗鞋机', '洗烘套装',
        '烘干机', '冰洗套装', '家用空调套装', '空调套装', '冰洗烘套装', '移动洗澡机', '全屋供暖', '集成家电',
        '中央热水', '全屋智慧家电解决方案', '集成热水器', '中央空调', '中央新风', '内衣清洗机', '多功能水槽电蒸箱',
        '厨房大电', '嵌入式电蒸箱', '集成灶', '消毒柜', '嵌入式保温抽屉', '气电混合灶具', '嵌入式微波炉', '烟灶套装',
        '嵌入式微蒸烤套装', '燃气灶', '嵌入式微蒸烤一体机', '水槽厨电一体机', '多功能餐吧柜', '洗碗机', '嵌入式电烤箱',
        '油烟机', '烟灶消套装', '集成烹饪中心', '电子鞋柜', '商用冷柜', '商用冷链', '冷库', '鲜花保鲜柜', '酒柜',
        '商用冰箱', '圆弧柜', '冰鲜台', '药品阴凉柜', '水果保鲜柜', '风幕柜', '岛柜', '衣物护理机', '厨房空调', '空调',
        '新风空调', '儿童空调', '空调挂机', '移动空调', '空调柜机', '笔记本电脑配件', '车载数码配件', '电教产品配件',
        '手机游戏辅助按键', '手机配件', '手机直播补光灯', '卡贴', '手机零部件', '手机电池', '卡槽', '卡托', '手机镜头',
        '手机挂件', '手机链', 'SIM卡相关', '手机饰品', '手机防尘塞', '配件礼盒套装', '手机支架', '手机座', '手机保护套',
        '手机屏幕总成', '手机游戏指套', '送话器', '手机贴膜', '手机贴纸', '手机红外遥控器', '发射器', '自拍杆',
        '手机同屏器', '取卡针', '手机数据线', '手机屏幕放大器', '手机充电器', '手机拍照配件', '手机镜头保护贴',
        '手机直播配件', '直播专用支架', 'SIM剪卡钳', '手机智能按键', '手机散热器', '笔记本电源', '笔记本键盘保护膜',
        '苹果视频线', '转换线', '笔记本屏幕贴膜', '笔记本膝上桌', '笔记本散热器', '降温卡', '笔记本个性小贴纸',
        '笔记本零部件', '笔记本电脑包', '笔记本多功能支架', '笔记本炫彩贴', '笔记本电池', '笔记本保护壳', '键盘刷',
        '数码相框', '电纸书屏幕贴膜', '电子书配件', '电子书灯', '电子书保护套', '电纸书防护包', '电子书手写笔',
        '电磁笔', '电纸书充电器', '数码相机电池', '数码相机配件', '屏幕保护膜', '数码相机包', '数码相机充电器',
        '数码相机适配器', '数据连接线', '家电影音周边配件', '分压盒', '隔离器', '耦合器', '网络切换器', 'BNC头', 'RF头',
        'VGA切换器', 'AV切换器', '机顶盒共享器', 'RCA头', '射频器', '分配器', '分频器', '分支器', 'F头', '3D立体眼镜',
        '便携电源', '3G无线上网卡设备', '数码周边', '数码家电保护贴', '对讲机设备', '对讲机配件', '相机色卡',
        '摄影周边设备', '校色仪', '气吹', '白平衡镜', '摄像滑轨', '外拍灯', '云台监视器', '影室灯', '辅助道具类',
        '快装板', '单反', '单电电池', '单电充电器', '反光器具', '相机背带', '脚架配件', '读卡器', '热靴水平仪',
        '相机挂绳', '滤镜', '相机专用遥控器', '镜头笔', '广角镜', '无线传输设备', '镜头盖', '脚架包', '闪光灯',
        '擦屏布', '提词器', '遮光罩', '柔光器具', '相机眼罩', '灯附件', '镜头袋', '镜头筒', '摄影梯', '单电适配器',
        '闪光灯配件', '摄影棚', '增距镜', '专业摄影背心', '单反机身盖', '单电专用电池电源', '影棚设备', '快门线',
        '高压气罐', '色彩管理', '镜头纸', '镜头布', '取景器', '箱配件', '云台电池与充电器', '对焦屏', '液晶屏保护膜',
        '防寒设备', '转接环', '防潮箱', '数码伴侣', '清洁用品', '摄影台', '静物台', '其他配件', '打印机色彩校正仪',
        '摄影包', '测光表', '灰板', '背景布类', '使用指南', '单反手柄', '箱具', '机身附件', '保护箱', '相机腕带',
        '相机闪光灯', '脚架接环', '脚架', '镜头附件', '毛刷', '干电池', '充电电池', '数码收纳整理包', '数码包', '收纳',
        '整理', '电池收纳盒', '线缆收纳器', '集线器', '耳机绕线器', '胶片相机配件', '胶片胶卷', '拍立得配件及周边',
        'Lomo配件及周边', '手持稳定器', '掌上电脑', '数码防丢器', '数据线', '移动支付终端机', '数码显微镜',
        '数码维修工具', '数码设备外接键盘', '数码防丢器保护套', '闪存卡转接套', '音乐枕', '手写笔', '触摸屏手套',
        '摄像机配件', '摄像机专用充电套装', '普通干电池', '18650电池', '纽扣电池', '通用电池充电套装', '18650电池盒',
        'USB数码周边', '平板电脑保护套', '平板电脑配件', '平板电脑外接键盘', '平板电脑数据线', '平板电脑底座',
        '平板电脑支架', '平板电脑充电器', '平板电脑包', '平板电脑屏幕贴膜', '平板电脑零部件', 'USB装饰配件',
        'USB保温盒', 'USB灯', 'USB吸尘器', 'USB翻页激光笔', 'USB风扇', 'USBHUB转接器', 'USB加湿器', 'USB烟灰缸',
        'USB电脑锁', '防盗器', 'USB延长线', 'USB暖手充电宝', 'USB加密狗', 'USB驱蚊器', 'USB其他配件', 'USB暖手鼠标垫',
        'USB多功能转换器', '移动电源', '户外电源', '背夹电源', '其它配件', 'MP4配件', '耳机充电仓', 'MP4充电器',
        '耳机线夹', '耳机贴膜', '耳机保护套', 'MP4保护套', '耳塞保护套', 'MP4支架', 'MP4屏幕保护膜', 'MP3发射器',
        'MP4连接线', '3c数码家电赠品', '影碟机', '蓝光', '高清播放器', '手机耳机', '解码器', 'Hifi音箱', '功放', '器材',
        'Hifi套装', '低音炮', '混响', '胆机', '话放', '耳放', '数字电视机顶盒', '耳机(麦)', '其它影音产品', '收音机',
        '随身听', '便携视听', '收音', '收录机', '手提CD', '面包机', '便携DVD', '便携VCD播放器', '复读机', 'CD随身听',
        '视频眼镜', 'TAPE磁带随身听', '卡拉OK音箱', '舞台设备', '均衡(舞台)', '打碟机', '分频器(舞台)', '效果器(舞台)',
        '调音台(舞台)', '点歌机', '专业音频放大器(舞台)', 'iPod', '录音笔', '网络高清播放器', '收音头', 'CD播放机',
        '耳机', '卡座', '家庭影院', '音响', '桌面音响', '回音壁音响', '无线', '蓝牙音箱', '电脑多媒体音箱',
        '拉杆广场音箱', '户外音响', '移动便携音箱', '麦克风', '工程解决方案', '无线耳机', '耳戴音频设备', '有线耳机',
        '真无线耳机', 'VGA线', '影音家电配件', '话筒配件', '电池', '电源适配器', '更多影音配件', 'hifi音响配件',
        'HDMI线', '线材', '电源插座', '接线板', '遥控器', '音频', '视频无线传输器材', '耳麦配件', '蓝牙耳机', '扩音器',
        '录像机', '家庭影院配件', '外置声卡', 'MP4耳机', '电视墙与操作台', '语音视频', '多媒体视频', '音频及会议系统',
        '视频会议', '中央控制系统', '网络存储设备', '网络安全', '网关', '智能控制终端', '路由器', '网卡配件',
        '其它网络相关', '区块链技术产品', '交换机', '无线高清', '数码线材', '网络摄像机', '视频监控', '摄像设备',
        '传输设备', '监控控制台', '显示控制', '网络图像设备', '宽带猫', '光猫', '机房布线', '天馈系统', '无线网络',
        '无线安全保密', '功率放大器', '光纤设备', '随身WiFi', '电脑', '网络工具', '网卡', '手机U盘', '移动固态硬盘',
        '普通U盘', '移动硬盘', '私有云存储设备', '闪存卡', '记忆棒', '学生平板', '电子辞典', '点读笔', '智能记事本',
        '手写本', '办公本', '学习手写板', '智能学习灯光一体机', '智能练字笔', '电子文教用品', '作业', '错题打印机',
        '学习机', '教育伴学机', '翻译笔', '电子阅读', '点读机', '传真', '通信设备', '3D打印机及配件', '扫描仪耗材',
        '其他办公用纸', '办公用纸', '复印纸', '打印机', '扫描仪', '胶卷', '复合复印机耗材', '投影机耗材',
        '其它办公设备配件', '包装设备', '标牌及耗材', '条码扫描', '采集器材', '其它办公设备', '喷绘机', '广告', '印刷',
        '绘图设备', '写真机', '丝印机', '广告板材', '烫金机', '压烫机', '物料基材', '晒图机', '平板', 'UV打印机',
        '条幅机', '磁盘刻录存储类', '复合复印机', '激光打印设备', '智慧零售设备', '门禁考勤器材', '装订耗材', '保险箱',
        '油墨', '其它耗材', '办公设备配件及相关服务', '收银机', '收银设备', '其他收银机', '其他办公用品', '计算器',
        '印刷制品', '纸张本册', '装订用品', '办公展示', '胶粘用品', '裁剪用品', '绘图测量用品', '财会用品', '碎纸机',
        '墨粉硒鼓耗材类', '验钞', '收款机及配件', '办公线材', '高拍仪', '其他会议设备', '会议音频视频',
        '语音转写笔记本', '会议平板', '真空包装机', '封装设备', '其他封装设备', '服务类', '打印机耗材', '保管箱',
        '门禁闸机', '考勤机', '图像解析服务器', '摄像头', '面板机（人像识别）', '边缘计算盒子', '投影机', '其他打印设备',
        '喷墨打印设备', '墨水', '集成电路（IC）', '冷却和热管理', '马达', '触摸屏', '触控屏', '多媒体与显示器件', 'OLED',
        '显示器件', '显示屏', 'LCD液晶屏', 'LED屏', 'TFT屏', '电子胶', '密封胶', '硅胶', '晶振与频率元件', '开关零件',
        '按钮零件', '电路板', '分立器件', '磁铁及制品', '无源元件', '物联网', '光电器件', '服务器及零部件', '线类',
        '电源及电源管理', '微处理器', '微控制器', '单片机', '接口', '功能模块', '电声器材', '电路保护',
        '手机信号放大器', '测试器材', '开发工具', '开发板', '开发套件', '开源硬件', '电子DIY', '创客', 'WIIU游戏软件',
        '游戏软件', 'PC游戏软件', '游戏数字版', 'PSV游戏软件', '任天堂 SWITCH游戏软件', '3DS游戏软件', 'XBOX游戏软件',
        'PS游戏软件', '其它游戏软件', '体感游戏机', '电玩周边', '游戏软件平台', 'XBOX专用配件', 'PSP专用配件',
        'WIIU专用配件', '方向盘', '游戏掌机', 'PS主机专用配件', '手柄充电器', '任天堂 SWITCH配件', '3DS专用配件',
        '摇杆', '家用游戏机', '手柄硅胶套', '游戏手柄', '任天堂掌机配件', '一次性拖鞋', '居家鞋', '凉拖', '棉拖(新)',
        '居家亲子拖鞋', '居家凉拖', '居家婚庆拖鞋', '居家棉鞋', '居家棉拖', '居家亚麻拖鞋', '床边毯', '钻石绣',
        '十字绣及工具配件', '十字绣成品', '十字绣套件', '十字绣工具', '绣线', '原版绣图', '绣布', '十字绣配件',
        '抱枕被', '靠枕', '抱枕新', '午睡枕', '靠垫', '床头靠垫', '腰靠垫', '茶几垫', '餐桌布艺', '餐巾', '桌布',
        '椅套', '桌旗', '桌椅脚套', '茶席', '桌椅套', '椅垫', '办公桌垫', '缝纫', '布艺DIY成品',
        '缝纫DIY材料、工具及成品', '热熔胶棒', '热熔胶枪', '锥子', '划粉', '尺子', '绣花机', '剪刀', '戳戳绣',
        '缝纫DIY配件', '配饰', '缝纫DIY工具套装', '缝纫机', '缝纫DIY材料套装', '刺绣套件', '地垫', '飘窗垫', '沙发垫',
        '美臀垫', '保健坐垫', '蒲团', '布料', '面料', '手工diy', '门帘', '窗帘门帘及配件', '蜂巢帘', '珠帘', '挂帘',
        '窗帘杆', '罗马杆', '垂直帘', '梦幻帘', '柜类遮挡帘', '窗帘轨道', '辅料配件', '窗纱', '电动窗帘整体套装',
        '卷帘', '定制窗帘', '成品窗帘', '线帘', '百叶帘', '折帘', '罗马帘', '全屋窗帘套餐', '窗帘面料', '纺织品填充物',
        '家纺布艺', '布料面料缝制服务', '挂毯', '壁毯', '面巾', '浴裙', '浴衣', '干发毛巾', '酒店毛巾浴巾',
        '浴巾毛巾方巾套装', '一次性浴巾', '汗蒸服', '手巾', '敷脸巾', '床头柜盖布', '防尘保护罩', '暖气片罩',
        '电视机罩', '烤火罩', '微波炉罩', '挂袋', '洗衣机罩', '净化器罩', '门把手套', '开关套', '电话套', '床头罩',
        '万能盖巾', '一次性防尘罩', '沙发套', '遥控器套', '遥控器篮', '钢琴罩', '空调罩', '酒瓶套', '垃圾桶罩',
        '饮水机罩', '电脑罩', '地毯', '休闲毯', '毛毯', '绒毯', '床品配件', '被套', '布艺蛋糕', '蛋糕毛巾', '床笠',
        '蚕丝被', '羽绒被', '棉被', '床垫', '床护垫', '榻榻米床垫', '枕巾', '床品定制', '定做', '床品套件', '床裙',
        '保健枕', '乳胶枕', 'U型枕', '羊毛被', '驼毛被', '化纤被', '乳胶被', '羽绒', '羽毛被', '棉花被', '床旗',
        '儿童床品套件', '枕套', '床幔', '蚊帐', '竹席', '牛皮席', '草席', '麻席', '乳胶席', '藤席', '冰丝席', '床盖',
        '厨房点火器', '点火棒', '厨用小工具', '厨房储物', '厨用取碗', '盘夹', '揉面袋', '旋盖小宝', '筷子筒', 'DIY模具',
        '食物罩', '开橙器', '剥橙器', '配菜', '备菜盘', '防油挡板', '面条机', '压面机', '沥水篮', '洗菜盆', '储物瓶罐',
        '厨房储物器皿', '冰淇淋勺', '磨刀器', '虾线刀', '剥虾器', '水果分割器', '泡酒瓶', '滤水器', '净水器',
        '保鲜膜切割器', '搅拌棒', '厨房小工具套装', '厨房储物架', '厨房置物架', '洗米筛', '封口机', '手用捣泥器',
        '鸡蛋加工', '饺子盒', '调味球', '按压式饮水器', '封口夹', '厨用取毛', '取刺用具', '蒸笼', '蒸格', '核桃夹',
        '瓜子钳', '铁指甲', '定时器', '提醒器', '配菜盘', '厨房电器配套用品', '手动榨汁器', '手动剥蒜器', '压蒜器',
        '敲肉锤', '多功能切菜器', '料理盒', '取盘器', '夹盘器', '防烫碗碟夹', '隔热架', '手动蔬菜甩干桶', '油壶',
        '厨房秤', '计量秤', '包饺子器', '一次性家用铝箔', '寿司DIY用具', '导热板', '手动果蔬脱水器', '甩水器', '绞肉机',
        '碎肉宝', '擀面杖', '火锅炉', '烹饪工具套装', '烹饪勺铲', '砧板', '菜板', '导热盘', '解冻盘', '小型燃气灶',
        '烘焙用纸', '烧烤', '烘焙用具', '烧烤刷', '烘焙转台', '一次性签子', '蛋糕模', '面粉筛', '手动打蛋器',
        '烘焙烤盘', '饼干模具', '蛋清分离器', '烘焙量勺量杯', '披萨铲', '烘焙刮板', '烘培DIY器具', '面包模具',
        '烧烤架炉', '烧烤DIY用具', '保鲜膜套', '一次性餐桌用品', '保鲜袋', '一次性碗、碟、盘', '一次性餐桌用品套装',
        '封口膜', '一次性筷子', '塑杯', '一次性手套', '纸杯', '可降解餐具', '环保餐具', '一次性杯垫、盖', '食物吸油纸',
        '保鲜膜', '一次性过滤袋', '调料袋', '缠绕膜', '一次性餐垫', '一次性餐盒', '鸡蛋托', '一次性桌布', '保鲜盖',
        '保鲜容器', '保鲜器皿', '保温袋', '保鲜盒', '密封罐', '摩卡壶', '咖啡器具', '奶罐', '咖啡套具', '打奶器',
        '咖啡勺', '法压壶', '滤压壶', '拉花缸', '拉花杯', '打奶缸', '磨豆机', '配套器具', '手冲壶', '咖啡机', '咖啡杯',
        '咖啡滤纸', '糖缸', '酒杯', '冰夹', '开罐器', '橡木酒具', '冰桶', '酒塞', '酒具套件', '酒签', '滤酒器',
        '开瓶器', '温酒器', '酒架', '分酒器', '漏斗', '醒酒器', '调酒器', '酒盒', '滤冰器', '家用酒壶', '不锈钢冰块',
        '挤柠檬器', '打蛋盆', '和面盆', '刻度盆', '西餐餐叉', '饭盒', '保温提锅', '韩国厨美餐具', '玻璃餐具套装',
        '隔热垫', '定制餐具', '扭曲勺', '餐具套装', '果盆', '果盘', '果篮', '西餐刀', '水果叉', '水果签', '餐具笼',
        '西餐勺', '筷套装', '餐用托盘', '西餐刀具', '便携', '折叠餐具', '蟹八件', '酒店餐具', '筷子', '配套瓷器',
        '焖烧杯', '吸管杯', '奶杯', '牛奶杯', '马克杯盖', '摇摇杯', '玻璃杯', '柠檬杯', '杯套', '隔热杯', '杯子套装',
        '情侣对杯', '水具套装', '马克杯', '防漏杯盖', '保温壶', '运动壶', '旅行壶', '随手杯', '冷水壶', '定制',
        '广告杯', '保温杯', '户外水杯', '防漏杯', '密封杯', '水素杯', '杯垫', '太空杯', '热水瓶', '智能水杯',
        '庭院摆件', '雕刻工艺', '炭雕（不含挂盘）', '玉雕', '相框', '画框', '烛台', '蜡烛', '无味蜡烛', '风铃及配件',
        '家饰软装搭配套装', '工艺扇', '车载摆件', '饰品', '内饰品', '工艺船', '创意饰品', '装饰盆', '装饰器皿',
        '装饰纸巾盒', '装饰坐盘', '挂盘', '储物罐', '阳光罐', '月光罐', '装饰碗', '果篓', '饰品盒', '装饰烟灰缸',
        '工艺伞', '（定制）照片墙', '照片墙', '（定制）照片', '照片书', '画片', '马桶贴', '贴饰', '墙贴', '美缝贴',
        '冰箱磁性贴', '冰箱贴纸', '瓷砖', '玻璃贴', '标示贴', '地贴', '开关贴', '其他贴饰', '衣柜贴', '电脑贴',
        '台面贴', '防滑贴', '镜面贴', '（定制）贴饰', '家具贴', '仪表箱', '电表箱遮挡装饰', '3D模型摆件', '家居钟饰',
        '执照框', 'DIY亲子装饰画', '装饰画', '印刷版画', '印刷油画', '标本类装饰画', '工艺画', '（定制）装饰画',
        '氛围灯画', '印刷书法', '无框画挂钟', '电表箱装饰画', '数字油画', '印刷国画', '现代装饰画', '其他印刷装饰画',
        '装饰架', '装饰搁板', '装饰挂牌', '装饰挂钩', '香薰精油', '家居香薰', '香薰摆件', '香薰灯', '器具', '精油皂',
        '香薰粉', '香托', '香盘', '香座', '香薰蜡片', '免插电扩香机', '喷香机', '散香器', '香薰DIY材料', '中式香',
        '经典熏香', '香薰融蜡灯', '香薰卡片', '香包', '香囊', '香篆', '香薰膏', '香薰石', '汽车香水', '车载香薰',
        '车载香膏', '香薰挥发液', '香薰礼盒', '香薰条', '香薰喷雾剂', '香薰配件', '其他工艺饰品', '壁饰', '流水摆件',
        '臀部按摩器', '按摩坐垫', '其他臀部按摩器', '按摩腰带', '背部按摩器', '按摩枕', '腹直肌修复仪', '其他腰',
        '背部按摩枕', '暖宫带', '揉腹仪', '曲度腰椎器', '按摩靠垫', '电吹风支架', '美发电器', '离子梳', '电动梳',
        '造型梳', '烫发器', '美发工具', '电动编发器', '理发器', '电吹风', '护发仪', '电动剃须刀', '修须刀',
        '修胡子造型器', '男士理容', '鼻毛修剪器', '经络保健器材', '足浴器', '足部按摩器', '足浴盆', '足底按摩器',
        '其他足部按摩器', '足疗机', '睡眠仪', '头部按摩器', '电动康复机', '按摩床', '生发仪', '按摩椅垫', '按摩头盔',
        'mini头部按摩器', '按摩床垫', '臀部', '腿部按摩器', '保健项圈', '其它健康', '其他头部按摩器',
        '脉冲式颈部按摩器', '肩部按摩器', '按摩披肩', '肩部按摩器配件', '电动U型枕', '揉捏式颈部按摩器', '发热围脖',
        '保健护具(护腰', '颈)', '其他膝', '全腿按摩器', '膝盖按摩器', '小腿按摩器', '膝部按摩器', '加热护膝',
        '家用护理辅助器材', '手臂按摩器', '手部', '其他手部按摩器', '手腕', '手指按摩器', '肘关节按摩器', '电子身高仪',
        '其他美容', '美发', '美体电器', '汗蒸袋', '电动丰胸仪', '洗脸仪', '干身器', '电动瘦身', '腿仪器', '挽脸器',
        '电子计步器', '电动美容修剪器', '洁耳器', '智能美妆镜', '化妆镜', '电动女士脱毛', '剃毛器', '电动睫毛卷翘器',
        '电子美妆镜', '电子美颜小魔镜', '皮肤测试仪器', '电动黑头仪', '护手仪', '电动修脚器', '个人清洁电器',
        '电动搓澡仪', '洗澡仪', '便携洁身器', '泡沫机', '洗手机', '电动修甲刀', '牙刷消毒器', '电动鞋刷', '人体干身机',
        '可视挖耳勺', '毛巾烘干消毒器', 'SPA机', '电子秤', '其它按摩器材', '其他部位按摩器', '车载电动腰靠',
        '电动塑身按摩仪', '电热敷盐包', 'MINI按摩器', '按摩贴', '车载电动头枕', '保暖护具', '桑拿房', '全身按摩垫',
        '按摩枪', '其它个人护理', '清洁美容工具配件', '家用保健器材配件', '经络保健器材配件', '新风', '电动口罩',
        '其他矫正器', '矫姿用品', '腿形矫正器', '护腰带', '矫姿腰靠', '骨盆矫正器', '矫姿带', '矫姿坐垫', '美眼仪',
        '眼部按摩器', '护眼仪', '牙刷消毒盒', '超声波洗牙器', '洁牙仪', '其它口腔护理设备', '牙刷头', '电子美牙产品',
        '水牙线', '家用冲牙器', '按摩椅', '三明治机', '厨房家电配件', '茶吧机', '泡茶机', '电动打奶器', '电动抽水器',
        '取水器', '烤串机', '电烤炉', '商用消毒洗涤设备', '电烤箱', '破壁机', '电饭煲', '冰淇淋机', '养生壶', '煎药壶',
        '商厨食品机械', '牛排机', '电陶炉', '饮水机', '微波炉', '电炖', '煮粥锅', '文火炉', '果蔬消毒清洗机',
        '多功能料理锅', '烹饪机器人', '智能厨房电器', '电动醒酒器', '炒菜机', '烹饪锅', '电热', '火锅', '绞肉', '碎肉',
        '绞菜机', '电茶炉', '煮茶器', '奶茶机', '餐具消毒机', '电蒸锅', '台式电蒸箱', '肠粉机', '其它商用厨电',
        '食物垃圾处理机', '食品保鲜真空机', '电动剥蒜器', '家用气泡水机', '电磁炉', '陶炉', '商厨制冷类设备',
        '食物烘干机', '磨粉机', '药材研磨机', '电压力锅', '电热水壶', '豆浆机', '蒸蛋器', '厨师机', '和面机',
        '空气炸锅', '商厨加热类设备', '台式净饮机', '电热饭盒', '原汁机', '榨汁杯', '榨汁机', '全屋净水系统', '电饼铛',
        '可丽饼机', '薄饼机', '电热杯', '搅拌', '料理机', '酸奶机', '电热炉', '其它厨房家电', '炒冰机', '芝士炉',
        '电烤盘', '刨冰机', '削皮机', '早餐吧', '豆芽机', '巧克力喷泉机', '电蒸炉', '爆米花机', '制冰机', '切片机',
        '切肉机', '迷你厨房电器', '商用水饮设备', '多士炉', '电动打蛋器', '干衣机', '消毒机', '活氧机', '换气扇',
        '排气扇', '布艺', '地毯清洗机', '冰箱除味器', '保温碟', '扫地机器人', '擦鞋器', '电风扇', '家用毛刷',
        '毛球修剪器（非电动）', '多功能空气质量检测仪', '吸尘器', '取暖桌', '踢脚线', '取暖器', '电热油汀', '快热炉',
        '电热膜', '小太阳', '远红外', '暖风机', '电子灭蚊器', '蒸汽清洁机', '挂脖空气净化器', '电子温湿度计', '电地垫',
        '吊扇', '快速制冷杯', '制暖杯', '超声波清洗机', '加湿器', '充气泵', '其它生活家电', '干手器', '其它日用家电',
        '节电器', '生活家电配件', '电暖手器', '电暖足器', '桌面空气净化器', '家用新风机', '空气循环扇', '无叶风扇',
        '香薰机', '电动清洁刷', '迷你衣物消毒机', '迷你生活电器', '测温机器人', '智能测温仪', '电话机(有绳', '无绳',
        '网络)', '除螨仪', '干鞋器', '加香机', '抽湿器', '除湿器', '美妆消毒器', '杀菌', '出霉家电', '其他消毒家电',
        '马桶消毒器', '衣物消毒机', '口罩消毒机', '消毒家电配件', '空气消毒机', '挂烫机', '空气净化器', '擦窗机器人',
        '迷你清洗机', '折叠清洗机', '空气净化机器人', '蒸汽拖把', '生活商用电器', '蒸汽刷', '手持挂烫机', '洗地机',
        '电动拖把', '电动扫把', '消毒水生成机', '电熨斗', '空调扇', '擦地', '拖地机器人', '水暖毯', '暖被机', '节日',
        '派对庆典用品', '保暖手套', '怀炉', '保暖用品', '暖手宝', '充电式热水袋', '桌上暖垫', '怀炉用品', '发热鞋垫',
        '暖腹宝', '保暖鞋', '暖脚宝', '暖垫', '热水袋套', '保暖披肩', '创意礼品', '美体用品', '塑身塑形', '增高用具',
        '增高用品', '束腿带', '塑身用品', '美容小工具', '指纹清洁纸', '家居健康用品', '应急去污宝', '竹炭包', '炭盒',
        '活性炭', '抑菌卡', '热水袋（注水）', '居家日用套装', '一次性鞋套', '鞋用品', '鞋套', '烘鞋器', '靴夹', '鞋拔',
        '鞋撑', '鞋塞', '鞋套机', '鞋刷', '鞋擦', '子孙桶', '婚庆用品', '拱门', '婚庆展台', '婚庆门亭', '帷幔装饰',
        '伴手礼', '椅背纱', '礼花', '礼炮', '礼金簿', '签名册', '请柬', '桌裙蓬蓬纱', '手腕花', '席位卡', '花轿',
        '糖盒', '糖盒配件', '颁奖托盘', '吊顶纱幔', '喜碗', '敬茶杯', '交车蝴蝶结', '仿真花瓣', '婚房布置套装', '路引',
        '婚庆印章', '婚庆公仔', '礼金箱', '婚房装扮用品', '拉花', '婚庆绢花', '喜字', '婚庆跪垫', '堵门', '游戏道具',
        '新娘配件', '书写板', '冰垫', '迷你风扇', '冰贴', '冰枕', '降温喷雾', '扇子配件', '美发剪', '园艺剪',
        '家用五金工具', '针织机', '家用梯', '照明电筒', '缝纫配件', '节日装扮用品', '装扮用品', '面具', '南瓜灯',
        '装饰灯', '甜品台装饰', '哨子', '飘空气球', '装扮布置套餐', '喷彩', '喷雪', '兔子灯', '整蛊用品', '生肖挂饰',
        '毛条', '孔明灯', '充气用品', '节庆布艺用品', '荷花灯', '河灯', '气球', '雨棚', '雨具', '防雨', '防潮',
        '抽屉垫', '挡雨帽', '防雨布', '伞架', '伞配件', '雨罩', '创意钥匙包', '防丢器', '相册', '相簿', '创意摆件',
        '招财猫', '创意抱枕', '创意颈枕', '许愿瓶', '幸运星瓶', '创意零钱包', '创意坐垫', '天气瓶', '风暴瓶', '储蓄罐',
        '金箔花', '定制礼盒', '定制礼品套组', '创意贴纸', '钥匙扣', '其他礼品', '创意礼盒', '礼品套组', '设计灯',
        '创意陶瓷', '设计玩具', '时尚烟灰缸', '创意根雕', '创意风筝', '海螺', '贝壳', '珊瑚', '香皂花', '创意玩偶',
        '纱窗', '纱门', '灭蚊灯', '吸蚊机', '灭蝇灯', '粘蝇纸', '防蚊贴', '防蚊手环', '苍蝇拍', '电蚊拍', '祛螨剂',
        '除螨凝胶', '防霉防蛀', '物理驱蚊工具', '驱蚊挂件', '汽车防虫网', '灭鼠笼', '捕鼠器', '超声波驱蚊器',
        '电子驱蚊器', '驱蚊草凝胶', '物理驱虫工具', '除螨垫', '祛螨包', '物理除螨工具', '驱蚊扣', '一次性洗脸毛巾',
        '护目镜', '防护用品', '眼贴', '一次性防护帽', '口罩防丢链', '防护服', '蒸汽面罩', '防护鞋', '安全帽', '护腰',
        '护肩', '护颈', '胸部防护用品', '防打鼾用品', '护腕垫', '手部防护用品', '口罩滤芯', '口罩滤片', '防护面具',
        '腿部防护用品', '防护手套', '口罩护耳', '防勒带', '腕部防护用品', '腰部防护用品', '隐形鼻罩', '鼻罩',
        '肘部防护用品', '头部防护用品', '一次性口罩垫', '反光配件', '反光穿戴用品', '膝部防护用品', '肩部防护用品',
        '防护耳罩', '隔音耳塞', '颈部防护用品', '浴室用品配件', '卫浴', '置物用具', '打泡器', '洗漱杯', '卷纸器',
        '纸巾架', '马桶刷', '厕所刷', '毛巾挂', '毛巾架', '起泡网', '浴室用品套件', '浴罩', '坐浴盆', '挤牙膏器',
        '浴帘杆', '水塞', '浴帘配件', '吹风机置物架', '管道疏通器', '浴帘', '粘钩', '下水道垃圾夹', '人体秤',
        '一次性马桶刷', '足浴桶', '卫生间踏板', '杯架', '过滤器', '马桶套', '马桶座圈', '管道清洁棒', '痰盂',
        '智能牙刷架', '牙刷架', '牙具座', '马桶置物架', '沐浴桶', '沐浴盆', '皂网', '乳液器', '便携淋蓬头',
        '厨卫防水贴', '起泡瓶', '浴缸置物架', '泡脚袋', '马桶提盖器', '地漏防臭器', '浴室角架', '皂盒', '下水道密封圈',
        '分装瓶', '个人洗护清洁用具', '束发带', '一次性浴帽', '指甲刀', '美发棒', '手动剃头刀', '搓澡海绵', '便携用镜',
        '卷发球', '搓澡巾', '呕吐袋', '鼻毛剪刀', '汽车清洗手套', '车载清洁用具', '汽车玻璃防雾剂', '驱水剂', '地胶',
        '汽车清洁软胶', '车载垃圾桶', '车载折叠马桶', '车用水桶', '防雾湿巾', '脸盆', '家务', '地板清洁用具',
        '微波炉清洁器', '围裙', '海绵擦', '家政清洁保洁工具套装', '除尘掸', '掸头', '杯刷', '瓶刷', '刮刮乐拖把',
        '水槽沥水袋', '静电除尘拖把', '百洁布', '一次性围裙', '空调过滤膜', '围裙套装', '清洁喷壶', '旋转拖把',
        '水槽过滤网', '拖把配件', '家务手套', '常规家务手套', '垃圾桶', '垃圾架', '玻璃清洁器及配件', '油烟机过滤膜',
        '静电除尘纸', '加液刷', '一次性抹布', '垃圾夹', '垃圾袋', '垃圾袋用品', '扫把及扫把头', '喷水拖把', '抹布',
        '擦地拖鞋', '胶棉拖把', '桌面清洁套装', '地板粘尘', '平板拖把', '钢丝球', '擦机布', '水拖', '厨房擦手巾',
        '簸箕', '鞋罩', '靴罩', '家庭防尘用具', '电视罩', '开关防尘贴', '空调防尘罩', '车罩', '按摩椅防尘罩', '沙发罩',
        '冰箱防尘罩', '电扇', '风扇防尘罩', '遥控器防尘套', '空调挡风板', '餐桌罩', '西服罩', '被子防尘袋',
        '其他防尘罩', '电脑防尘罩', '微波炉防尘罩', '挂烫机防尘罩', '电话防尘罩', '吹风机防尘袋', '家用收纳手推车',
        '家庭整理用具', '居家搬运带', '排插固定器', '尼龙绳', '挂钩', '切药器', '冰柜置物架', '被子固定器',
        '书桌收纳置物架', '桌面隔板', '绕线器', '桌脚垫', '橡筋', '双面贴物器', '粘灰尘器', '路由器收纳盒',
        '家具防倾倒器', '洗衣机置物架', '夹子', '收纳夹子', '整理架', '置物架', '暖气片置物架', '洗衣机底座', '绳子',
        '爬墙固定器', '整理隔板', '帽子收纳架', '阳台置物架', '桶装水支架', '主机箱托架', '抽气泵', '其他整理用品',
        '挂门置物架', '插线板收纳盒', '车载收纳', '车用置物袋', '置物箱', '免打孔壁挂晾衣架', '衣物洗', '护理用具',
        '叠衣板', '洗护球', '晾衣杆', '电动毛球修剪器', '烫衣板', '护洗袋', '晒衣篮', '大型晒衣架', '领带架', '衣架',
        '搓衣板', '烘干衣架', '金属衣架', '衣叉', '裤架', '烫衣板及配件', '除尘刷', '粘尘纸', '简易衣帽架',
        '洗衣吸毛器', '置地', '升降晾晒衣架', '衣物除尘滚', '粘毛滚', '小型晒衣架', '多夹子晾衣架', '晾衣架专用遥控器',
        '其它用具', '洗衣粉收纳盒', '家庭收纳用具', '毛绒玩具收纳桶', '收纳瓶', '收纳凳', '美妆蛋收纳盒', '乳牙收纳盒',
        '壁式收纳盒', '收纳筐', '零食收纳筐', '洗脸巾收纳盒', '手表收纳盒', '棉签收纳盒', '口红收纳包', '橱柜收纳筐',
        '便携购物车', '购物车袋', '包包收纳盒', '面膜收纳盒', '火柴收纳盒', '脱毛仪收纳包', '电子烟收纳盒',
        '顶天立地收纳杆', '缝隙柜', '指甲油收纳盒', '运动器材收纳用具', '化妆箱', '吸尘器收纳架', '收纳洞洞板',
        '衣架收纳架', '口罩收纳盒', '果蔬收纳袋', '卸妆棉收纳盒', '手帐收纳盒', '牙套收纳盒', '纸尿裤收纳盒',
        '镊子收纳盒', '手机收纳盒', '剃须刀收纳包', '便携衣架', '旅行收纳用具', '旅行收纳套装', '衣物收纳袋',
        '内衣收纳袋', '其他收纳', '其它成套家具', '卧室成套家具', '功能房成套家具', '门厅成套家具', '书房成套家具',
        '客厅成套家具', '餐厅成套家具', '柜子配件', '飘窗柜', '书柜', '角柜', '衣柜', '简易衣柜', '吊柜', '壁柜',
        '餐边柜', '连体书桌柜', '门厅', '玄关柜', '玄关架', '斗柜', '顶箱柜', '电视柜', '其它柜类', '家用陈列柜',
        '鞋柜', '药柜', '家政柜', '佛柜', '佛龛', '床头柜', '茶几', '角几', '边几', '其它几类', '炕几', '套几',
        '根雕花架', '根雕类', '根雕茶几', '根雕茶桌', '根雕凳子', '坐具配件', '凳类', '电竞椅', '椅类', '壁炉架',
        '壁炉柜', '书架', '木制', '板式酒架', '鞋架', '搁板', '其他架类', '书报架', '面盆架', '格架', 'CD架', '衣帽架',
        '组合衣架', '多宝格', '博古架', '家用雨伞架', '弹簧床垫', '床垫类', '卷包', '折叠床垫', '凝胶床垫', '水床垫',
        '圆床垫', '3D床垫', '棕榈床垫', '记忆棉床垫', '乳胶床垫', '椰棕床垫', '复合床垫', '海绵床垫', '其他床垫',
        '智能床垫', '儿童成套家具', '儿童家具', '儿童沙发', '儿童学习桌', '高低', '子母床', '儿童床垫', '座屏', '折屏',
        '插屏', '挂屏', '椅子', '设计师家具（NEW）', '桌子', '穿衣镜', '家具辅料', '适老家具', '麻将桌', '桌子配件',
        '供桌', '家用茶台', '茶桌', '棋桌', '餐桌', '电脑桌', '梳妆台', '书桌', '经桌', '电动升降桌', '折叠桌', '琴桌',
        '其它桌类', '木屋凉亭', '庭院家具', '垃圾筒', '伞具', '坐具', '桌椅套件', '户外秋千', '午休床', '藤艺床',
        '床架', '床板', '板木结合床', '衣柜床', '实木床', '布艺床', '皮艺床', '拔步床', '架子床', '床配件', '板式床',
        '铁艺', '钢木床', '罗汉床', '衣箱', '藏箱', '扣箱', '遮挡箱', '钥匙盒', '家用保险箱', '玄关台', '台类', '条案',
        '岛台', '吧台', '其它案台', '皮艺沙发', '沙发类', '功能沙发', '充气沙发', '皮布沙发', '沙发床', '贵妃椅',
        '布艺沙发', '竹沙发', '懒人沙发', '沙发凳', '实木沙发', '沙发配件及辅料', '铁艺沙发', '母婴家具', '桑拿',
        '足浴', '健身家具', '中岛', '流水台', '商业配套设施', '收银台', '更衣柜', '工具车', '清洁柜', '保洁储物柜',
        '寄存柜', '快递柜', '培训家具', '发廊', '美容家具', '医院', '药店', '复健家具', '仓储家具', '商业美陈',
        '服饰家具', '阅览桌', '书店', '音像家具', '杂志报刊架', '餐饮', '烘焙家具', '景观道具', '景观家具',
        '公共卫生服务设施', '城市家具', '交通服务设施', '美化丰富空间设施', '信息服务设施', '公共休闲服务设施',
        '网咖家具', '会展家具', '展柜', '大板桌', '接待台', '钥匙箱', '办公椅', '办公桌', '公共休闲系列', '报刊架',
        '办公柜类', '屏风隔断', '成套办公家具', '会客沙发', '隔音房', '静音仓', '成套商业家具', '文具家具', '酒吧',
        'KTV家具', '坯料半成品', '半成品家具', '商用活动房', '结构棚', '酒店家具', '超市家具', '校园教学家具', '系统窗',
        '其它窗', '断桥铝窗', '防盗窗', '铝包木窗', '无框阳台窗', '铝合金窗', '平开窗', '外悬窗', '推拉窗',
        '定制背景墙', '和室椅', '榻榻米空间', '榻榻米垫', '和室窗', '榻榻米定制', '和室门', '和室几桌', '升降桌',
        '榻榻米辅料', '扣板模块', '集成吊顶', '电器模块', '蜂窝吊顶', '集成吊顶套餐', '配件模块', '书房空间定制',
        '全屋空间定制', '娱乐室空间定制', '影音室空间定制', '全屋空气调节系统', '健身房空间定制', '客厅空间定制',
        '储藏室空间定制', '全屋净化系统', '阳台空间定制', '内遮阳 ', '外遮阳系统定制', '酒窖空间定制', '定制衣帽间',
        '车库空间定制', '儿童房空间定制', '卧室空间定制', '阳光房定制', '移门', '全景门', '防火门', '门附件', '室内门',
        '进户门', '智能防盗门', '庭院门', '整体厨柜及配件', '整体吊顶定制', '缩颈龙骨', '楼梯', '楼梯踏步板',
        '楼梯立柱', '楼梯扶手', '整体楼梯', '定制淋浴房', '整装定制', '功能背景墙', '集成墙面', '护墙板附件',
        '低温热水辐射地暖', '地暖', '暖气片', '低温电热辐射地暖系统', '定制柜类', 'SPC地板', '地板', '防火地板',
        '漏缝地板', '格栅地板', '隔音地板', '特殊用途地板', '竹地板', '强化复合地板', '户外地板', '实木地板',
        '实木复合地板', '其他地板', '软木地板', '地板附件', '地板革（PVC地板）', '定制护墙板', '定制衣柜', '局部改造',
        '局部装修', '局部软装定制', '局部主材套餐', '局部硬装翻新', '局部整体翻新', '开荒保洁', '家庭设计', '工程设计',
        '装修污染检测', '装修检测治理', '装修污染治理', '设计审核', '节点监理', '预算审核', '全程监理', '验房',
        '家庭保维修', '清包施工', '家庭装修', '半包装修', '全包装修', '全案装修', '工程装修', '单项安装', '软装配饰',
        '装修检测服务', '涂料（乳胶漆）', '美缝剂', '油漆', '工业漆', '自喷漆', '油漆辅料', '艺术漆', '木器漆',
        '门窗密封条', '雕花件系列', '排水沟盖板', '基础材料耗材', '化粪池', '家用五金', '家具五金', '插销', '窗用配件',
        '按弹器', '反弹器', '拉手', '合页', '其他五金件', '门用配件', '智能门锁', '砂岩', '新型装饰材料', '贴墙纸配件',
        '配件专区', '贴砖配件', '玻璃窗配件', '玻璃配件', '化学注浆', '注浆材料', '防水材料', '透水砖', '轻质砖',
        '红砖', '多孔砖', '其它基础建材', '水泥', '玻璃', '木方', '家具地板修补膏', '清洁修复', '墙面修补膏', '板材',
        '隔音材料', '天然大理石', '硅钙板', '阳光房', '石膏板', '丁基胶', '胶类', '免钉胶', '焊接胶', '隔断墙',
        '隔热材料', '人造大理石', '线条', '水管管材', '微晶石', '抛晶砖', '水磨石砖', '玻化砖', '釉面砖', '微水泥瓷砖',
        '通体砖', '岩板', '马赛克', '其它类瓷砖', '瓷砖背景墙', '木纹砖', '仿大理石瓷砖', '仿古砖（包括文化石）',
        '瓷砖装饰附件', '无纺布墙纸', '墙咔', '柔性墙板', '立体墙布', '玻纤壁布', '石英壁布', '海基布', '纯纸墙纸',
        '绒面墙纸', '铝箔墙纸', '防水贴纸', 'PVC墙纸', '定制壁画', '其它材质类墙纸', '沙粒墙纸（喷砂壁纸）', '自贴墙纸',
        '自粘墙纸', '卫浴配件', '卫浴用品', '可移动坐便器', '全卫浴套装', '角阀', '壁挂式智能坐便器', '马桶盖',
        '坐便器盖板', '净身妇洗器', '淋浴房', '卫浴水箱', '地漏', '蹲便器', '智能马桶', '一体智能坐便器', '卫浴龙头',
        '卫浴阀门系统', '冲水器', '喷头', '喷枪', '浴室壁挂凳椅', '智能马桶盖', '坐便椅', '坐便凳', '马桶凳', '拖把池',
        '坐便器配件', '马桶', '坐便器', '小便器', '卫浴五金', '卫浴家具', '灯暖式浴霸', '浴霸', '风暖式浴霸',
        '多功能浴霸', '凉霸', '智能浴霸', '排风扇', '墙布', '壁布', '布面墙纸', '保养系列', '环保', '除味', '保养',
        '环保系列', '固定式晾衣架', '晾衣架', '升降晾衣架', '伸缩晾衣架', '隐形晾衣架', '智能晾衣架', '晾衣架配件',
        '背景墙软包', '床头套', '工艺软包', '厨房主材套装', '智能水槽', '厨用垃圾桶', '智能厨房龙头', '厨盆', '水槽',
        '商用厨房', '防溅头', '厨房龙头', '米桶', '水槽皂液器', '拉篮', '厨房阀门系统', '厨房挂件', '其它厨房配用件',
        '管道阀门', '阀门系统', '燃气阀门', '除醛仪器', '除醛系列', '除醛果冻', '除醛喷雾', '阳台主材套餐', '阳台',
        '感应灯', '家居类灯饰', '镜前灯', '化妆补光灯', '取暖灯', '奇光板', '量子灯', '投影灯', '氛围装饰灯', '小夜灯',
        '植物生长灯', '橱柜灯', '杀菌灯', '落地灯', '灯具配件', '家装类灯饰', '壁灯', '吊灯', '风扇灯', '吸顶灯',
        '成套灯具', '支架灯', '其它灯具灯饰', '其它光源', '光源', 'LED光源', '卤钨灯', '荧光灯', '白炽灯', '屏幕灯',
        '护眼灯饰', '护眼吸顶灯', '落地护眼灯', '台灯', '钢琴灯', '轨道磁吸灯', '无主灯类灯饰', '线性灯', '格栅',
        '面板灯', '射灯', '斗胆灯', '踏步灯', '地脚灯', '全屋灯光设计套装', '格栅灯', '筒灯', '室外灯饰',
        '景观庭院灯饰', '道路灯具', '端景台灯饰', '工矿灯具', '应急灯', '金属盒', '铝板', '铝扣板', '铝吊顶', '铝方通',
        '铝材', '铝型材', '铝合金', '铝百叶', '其他铝制品', '金属加工件', '五金加工件', '模具钢', '工具钢', '特钢',
        '钢材', '圆钢', '钢管', '扁钢', '槽钢', '螺纹钢', '角钢', '钢板', '金属罐', '丝网', '金属网', '不锈钢',
        '金属粉末', '有色金属', '金属丝', '硬质合金', '其他金属制品', '铜材', '金属结构件', '风机', '排风设备',
        '制冷设备', '美容店设备', '清理设备', '商用洗衣设备', '眼镜店设备', '商用炉灶', '休闲食品加工设备',
        '食品加工设备', '果蔬加工设备', '豆制品加工设备', '肉制品加工设备', '解冻机', '保鲜柜', '冷藏柜', '食品搅拌机',
        '开水器', '开水炉', '饮料加工设备', '米面加工设备', '奶油机', '鲜奶机', '脱油机', '打蛋机', '洗蛋机', '磕蛋机',
        '加油站设备', '电子产品制造设备', '交通控制管理设备', '化工设备', '制鞋机械', '其他机械设备', '管道疏通机械',
        '工程机械', '建筑机械', '挖掘机', '混凝土泵', '打桩机', '混凝土泵车', '铲运机', '混凝土搅拌车', '推土机',
        '自卸车', '翻斗车', '打夯机', '压路机', '工程钻机', '散装水泥车', '装载机', '摊铺机械', '筑路机械', '捣固机',
        '放射性污染防治和处理设备', '环境污染防治设备', '大气污染防治设备', '消音降噪设备', '垃圾焚烧炉',
        '水质污染防治设备', '工业加湿器', '造纸', '纸加工设备', '口罩机', '涂装设备', '其他包装设备', '缠绕机',
        '裹包机', '充填机', '打标机', '打码机', '喷码机', '贴标机', '打包机', '捆扎机', '孵化器', '孵化设备', '压缩机',
        '吸奶机', '挤奶机', '集乳器', '乳品设备', '储罐', '乳品配套设备', '乳品生产设备', '乳化机', '节能设备',
        '调味品加工设备', '其他食品加工设备', '酿酒设备', '烘焙设备', '炉灶', '炊事设备', '洗菜机', '冷饮机',
        '糕点设备', '糖果加工设备', '干燥机', '干燥箱', 'LED生产及检测设备', '机床', '提香机', '茶叶设备', '理条机',
        '筛选机', '烘炒机', '揉捻机', '杀青机', '橡胶设备', '空分设备', '自动售票机', '售卡机', '取票机', '印刷设备',
        '模具加工设备', '通信传输设备', '锅炉', '生物识别技术设备', '汽修设备', '冶炼设备', '矿山专用设备',
        '美发店设备', '理发设备', '雷达', '导航设备', '过滤设备', '防雷电设备', '视觉光源', '机器视觉', '工业相机',
        '摄像机', '自动化视觉系统及设备', '工业镜头', '远心镜头', '图像采集卡', '吹膜机', '塑料机械', '吹塑机',
        '挤出机', '硫化机', '拉丝机', '压塑机', '注塑机', '成型机', '制袋机', '其他塑料机械', '造粒机', '消毒灭菌设备',
        '制药设备', '园林设备', '畜牧设备', '广播电视传媒设备', '空气净化设备', '试验机', '电影放映设备', '砂磨机',
        '粉碎设备', '研磨机', '破碎机', '粉碎机', '全车改装套件', '汽车改装', '赛车文化', '汽车服务', '加油卡',
        '通用脚垫', '汽车内饰用品', '手刹套', '档把套', '套饰套装', '汽自驾野营', '停车号码牌', '包真皮座套', '防护垫',
        '一次性汽车脚垫', '专车专用座套', '驾驶室脚踏板', '腰靠', '驾车个人用品', '一次性方向盘保护套', '车载手机支架',
        '车载儿童增高垫', '通用座套', '货厢保护垫', '一次性汽车座椅保护套', '汽车挂件', '车用眼睛夹', '票据夹',
        '通用座垫', '专车专用脚垫', '汽车儿童安全座椅', '车用衣服架', '车载旅行床', '车用水杯架', '饮料架',
        '汽车内饰贴片', '车载儿童颈枕', '汽车车标', '专车专用座垫', '车用烟灰缸', '专车专用后备箱垫', '方向盘套',
        '安全座椅凉席', '车牌架', '牌照托', '头枕', '通用后备箱垫', '车用笔记本架', '车用挂钩', '车用纸巾盒',
        '车用防踢垫', '防磨垫', '驾驶证件套', '车载儿童坐垫', '内饰改装', '儿童安全带套', '延长带', '中控台避光垫',
        '其他内饰', '驾乘用品', '逆变器', '汽车电子', '电器', '汽车空调', '驻车空调', 'GPS导航软件', 'GPS导航模块',
        '车载发射器', '车载驱鼠器', '车用便捷式GPS导航', 'GPS充电器', '其它汽车电子用品', '车载阅读灯', '车用电扇',
        '暖风扇', '其它GPS导航配件', '车载碟盒', '蓝牙检测仪', '智能后视镜导航', '车载路由器', '门腕贴', '汽车外饰品',
        '外饰加装', '门腕', '汽车灯罩框', '其他汽车外饰品', '汽车固定踏板', '皮卡尾箱盖', '车用电子钟表',
        '汽车电动踏板', '刹车卡钳罩', '灯眉', '汽车地板改装', '尾喉', '消声器', '外饰改装套件', '内饰贴膜', '气门芯套',
        '导航贴膜', '加装', '装潢', '碳纤维改装件', '碳纤维件', '汽车氛围灯', '车窗饰条', '门槛条', '装饰性轮眉',
        '年检车贴', '汽车安全防护用品', '发动机底护板', '汽车车衣', '防撞胶条', '防划条', '司机护目镜', '车用窗帘',
        '其他汽车防护', '车用指南针', '指南球', '雪挡被', '孕妇安全带', '便利尿袋', '雨眉', '晴雨挡', '交通反光背心',
        '车载应急包', '破窗器', '遮阳伞', '多功能手电', '轮胎防滑链', '汽车防静电用品', '汽车防雨', '防雾膜',
        '车用密封胶条', '气压表', '胎压表', '酒精测试仪', '越野平衡仪', '后视提篮镜', '充电口防水', '遮阳挡',
        '汽车文化', '汽车美容护理工具', '维修', '汽保工具', '洗车', '维修保养', '空调滤芯', '滤芯', '空气滤芯',
        '天然气滤芯', '汽油滤芯', '机油滤芯', '转向系统', '油水分离器总成', '油水分离系统', '油水分离器', '供油系统',
        '动力系统', '进排气系统', '分电器', '点火系统', '高压线', '点火器', '点火线圈', '火花塞', '排挡杆', '内饰系统',
        '前风挡玻璃', '安全带及调节器', '天窗及配件', '车窗及其配件', '隔音隔热棉', '空调旋钮', '后风挡玻璃', '扶手箱',
        '座椅及附件', '刹车油', '油品', '柴机油', '手动变速箱油', '齿轮油', '汽车发动机机油', '转向助力油', '分动箱油',
        '冷冻机油', '自动变速箱油', '变速箱系统', '冷却系统', '防盗系统', '乘用车轮胎', '轮胎', '非乘用车轮胎',
        '保险杠', '外观件', '轮毂', '后备箱门', '尾翼', '顶翼', '倒车镜', '后视镜', '车门拉手', '越野车外侧脚踏板',
        '汽车包围', '后围', '车顶架', '车顶箱', '后杂物搁板', '车底防护板', '发动机挡板', '中网', '拖车钩', '电气系统',
        '雨刮器', '刹车片', '制动系统', '刹车鼓', '真空助力器', 'ABS泵支架', '刹车油管', '驻车制动器', '刹车蹄',
        '制动油壶', '制动总泵', '刹车泵（ABS）', '刹车卡钳', '刹车盘', '手刹拉手', '卡簧', '制动真空管', '刹车报警线',
        '制动弹簧', 'ABS感应线', '制动器挡板', '制动器总成', '手刹线', 'ABS油壶', '气动系统', '雾灯', '照明系统',
        'HID氙气灯', '防追尾灯', '车内灯', '汽车车灯透镜', '尾灯总成', '汽车灯泡', '越野射灯', '氙气灯安定器',
        '大灯总成', '备胎罩', '车用附件', '大视野后视辅助镜', '警示牌', '后备箱弹簧助力器', '车轮锁', '车位锁',
        '拉货灯', '代驾灯类', '电瓶搭火线', '备用油箱', '轮毂盖', '油箱盖', '门锁盖', '车用天线', '悬挂系统',
        '尿素系统', '车载蓄电池', '头盔干燥器', '摩托车骑士装备', '头盔耳机', '摩托车挡风被', '摩托车胎压监测仪',
        '摩托车遮阳伞', '摩托车USB充电器', '骑士包', '头盔饰配', '骑士手套', '摩托车导航', '对讲机支架', '摩托车雨衣',
        '蓝牙记录仪一体机', '摩托车行车记录仪', '赛车T恤', '骑士护具', '赛车裤', '摩托车头盔', '摩托车GPS定位',
        '摩托车整车订金', '摩托车车锁', '摩托车配件', '摩托车轮毂', '摩托车车灯', '摩托车坐垫', '摩托车喇叭',
        '摩托车排气管', '摩托车发动机', '摩托车导流罩', '摩托车钥匙', '摩托车离合器', '链盘', '气门', '气门组件',
        '启动杆', '刹车拉杆', '活塞', '摩托车火花塞', '整流器', '摩托车尾箱', '磁电机及组件', '摩托车尾翼', '弹簧',
        '气缸体', '起动电机', '曲轴', '摩托车化油器', '摩托车维修工具', '刹车护手', '摩托车氙气灯', '油箱', '刹车系统',
        '气缸盖', '点火装置', '摩托车防盗器', '活塞环', '摩托车后视镜', '方向阻尼器', '摩托车滤清器', '摩托车车架',
        '摩托车轮胎', '摩托车减震器', '摩托车齿轮', '气缸头', '摩托车电瓶', '摩托车仪表', '电瓶充电器', '摇臂',
        '摆臂轴', '皮带及传动组件', '摩托车前挡风', '摩托车拉线', '摩托车保险杠', '手把套', '摩托整车', '沙滩车',
        '飞行器', '摩托车防冻液', '摩托车装饰养护', '盖帽配饰', '摩托车脚踏板', '摩托车外壳', '摩托车刹车油',
        '摩托车漆面保护膜', '摩托车牌照架', '摩托车洗链器', '摩托车车衣', '贴膜', '摩托车燃油添加剂', '摩托车机油',
        '其他摩托车用品', '船舶配件', '船舶储能电池', '多控开关', '开关', '无线开关', 'wifi开关', '浴霸专用开关',
        '门铃开关', '防溅盒', '插卡取电开关', '调光开关', '触摸开关', '调速开关', '单控开关', '双控开关', '遥控开关',
        '感应开关', '报警按钮', '消防报警设备', '火灾显示盘', '总线控制盘', '壁挂消防广播功放', '警铃', '消防电话',
        '喷淋头', '回路板', '气体灭火控制盘', '壁挂广播控制柜', '吸顶式消防广播音箱', '消防稳压电源', '报警模块',
        '报警灯', '消防控制柜', '控制箱', '报警喇叭警号', '电视分配器', '电工配件', '接线端子', '电度表', '电笔',
        '其他电工配件', '电工胶带', '电工保险丝', '汇流排', '空气开关', '断路器', '漏电保护器', '交换器', '底盒',
        '烟雾报警器', '防盗报警器材及系统', '入侵检测设备', '水浸报警器', '家用单机温感探测器', '家用气体检测报警器',
        '安防配件', '阻门报警器', '报警主机', '家用单机烟感探测器', '智能电子脉冲围栏系统', '断电报警器',
        '开关插座套装', '插座', 'USB插座', '快充插座', '电话线', '电线', '网络线', '单芯线', '音响线', '护套线',
        '视频线', '电缆线', '硬盘录像机', '监控器材及系统', '成套监控系统', '视频监控测试仪', '字符叠加器',
        '音频跟随器', '识音器', '集音器', '光端机', '视频矩阵服务器', '成套监控设备', '监控摄像机', '视频采集卡',
        '视频解码器', '监控显示器', '音频采集卡', '画面分割器', '音频切换器', '监控器材配件', '视频转换器', '智能门铃',
        '可视门铃', '智能家庭', '智能开关', '配电控制柜', '布线箱', '弱电布线盒', '强电布线盒', '电线管配件',
        '电工套管', '电线管', '升降插座', '插头', '嵌入式插座', '转换插头', '卷线盘', '轨道插座', '快充',
        '无线充电排插', '轴承附属件', '机械五金', '百叶轮', '法兰（新）', '吊钩', '抓钩', '传动件', '滚筒', '管夹',
        '吊滑车', '滑动轴承', '化工管道及配件', '密封件', '管接头', '机械喷嘴', '阀门', '工作台', '树脂磨片', '切片',
        '其他机械五金（新）', '托辊', '炉头', '滚动轴承', '分离设备', '风速仪', '仪器仪表', '电阻测试仪', '测振仪',
        '粘度计', '测温仪', '吊秤', '验电器', '耐压测试仪', '水准仪', '测线仪', '测糖仪', '分光光度计', '相位表',
        '折光仪', '透光率计', '浊度计', '水份仪', '粗糙度仪', '农药残留检测仪', '辐射检测仪', '烟气分析仪', '数字电桥',
        '商用台秤', '工业台秤', '频率测试仪', '比色计及比色灯箱', '其它仪表仪器', '应变计', '温控仪', '测堵仪',
        '液位计', '垂准仪', '全站仪', '测湿仪', '密度计', '安规测试仪', '核相仪', '粒子计数器', '频闪仪', '照度仪',
        '气体探测仪', '电表', '压力开关', '测厚仪', '热像仪', '气体检测仪', '水质分析仪', '酒精检测仪',
        '电子负载测试仪', '余氯测定仪', '示波器', '张力计', '电热工具', '水平仪', '频谱分析仪', '工业环境监测系统',
        '校准仪', '计价器', '离子计', '探伤仪', '无损检测仪', '测量台架', '物位计', '料位计', '经纬仪', '流量计',
        '土壤分析仪', '热量表', '双金属温度计', '转速表', '气象仪', '对中仪', '噪音仪', '推拉力计', '硬度计',
        '电位滴定仪', '酸度计', '压力式温度计', '测亩仪', '兆欧表', 'usb测试仪', '测速仪', '电导率仪', '电阻温度计',
        '热电偶温度计', '细菌微生物检测仪', '漏电测试仪', '电容电感测试仪', '皮带秤', '色谱仪', '电镀电容表',
        '电能质量分析仪', '钳形表', '熔点仪', '色差仪', '水表', '叉车秤', '压力表', '加速度计', '燃气表',
        '压差计及压差表', '电能表校验装置', '漏水测试仪', '测距仪', '墙体探测仪', '推力球轴承', '调心滚子轴承',
        '调心球轴承', '圆柱滚子轴承', '直线运动轴承', '滚针轴承', '推力滚子轴承', '圆锥滚子轴承', '外球面球轴承',
        '转盘轴承', '回转轴承', '组合轴承', '深沟球轴承', '关节轴承', '角接触球轴承', '工具组合套装', '手动工具',
        '汽修汽保工具', '套筒及配件', '工具包', '夹持类工具', '铲胶器', '划线工具', '其他手动工具', '电子电工工具',
        '焊接喷涂', '测量工具', '玻璃吸盘', '锉、刨', '冲、撬棒', '锯和锯条', '螺丝批、旋具头', '涂刷工具', '光饰机',
        '电动工具', '电锯', '雕刻机', '地钻', '水钻机', '云石片', '直磨机', '电动坡口机', '热溶胶枪', '界铝机',
        '电动螺丝批', '电动打胶机', '割草机', '电刨', '砂带机', '电动批头', '车用洗车机', '设备', '抛光机', '螺丝机',
        '电磨', '角磨机', '电钻', '砂纸机', '电锤', '洗车水枪', '倒角机', '电动扳手', '磨刀机', '电剪', '修边机',
        '电锯片', '电动套丝机', '切割机', '砂轮机', '其它电动工具', '电力配件', '机电五金', '压力容器', '内燃机',
        '电机配件', '发电机', '其他机电五金', '压力管道', '电梯配件', '电热设备', '焊接设备', '家用电梯', '电动机',
        '变速机', '车底检查镜', '安全检查设备', '红外线测温系统', '测温门', '金属探测器', '无线电波探测仪',
        '气动捣固机', '气动工具', '气动扳手', '气镐', '气动棘轮扳手', '气锤', '气动磨光机', '气动铆钉机',
        '气动工具配件', '吹风枪', '气钉枪', '其他气动工具', '气动搅拌机', '热风枪', '气动封箱机', '施工除尘器', '气鼓',
        '气动冷压接钳', '气动元件', '气动螺丝刀', '气铲', '气锹', '液压工具', '液压', '起重工具', '钻头', '刃具',
        '铣刀类', '铰刀类', '镗刀', '车刀', '滚刀', '其他刃具', '拉刀（新）', '板牙', '丝锥', '刨刀', '膨胀类', '紧固件',
        '垫圈', '铆钉', '挡圈', '其它紧固件', '螺钉', '螺柱', '螺母', '组合件和连接副', '螺栓', '坠落防护', '劳保用品',
        '眼部、面部防护', '消防器材', '绳网', '手部防护', '交通安全保护', '呼吸防护', '头部防护', '足部防护鞋', '灭火器',
        '不间断电源', '应急电源', '电气控制', 'LED设备', '配电输电设备', '变频器', '稳压器', '蓄电池', '低压电气',
        '互感器', '变压器', '工控系统及装备', '电线电缆', '继电器', '电工电器成套设备', '褥疮垫', '护理垫（器械）',
        '康复理疗', '理疗仪', '便厕用具（器械）', '吸痰器', '牙齿脱敏剂', '保健护理', '中医保健', '洗澡椅', '牙齿美白仪',
        '医用乳膏（器械）', '牙周治疗仪', '失眠贴(器械）', '膏药贴（器械）', '造口袋', '牙齿矫正器／隐形牙套／义齿',
        '针灸器具（器械）', '生发仪（器械）', '颈椎牵引器（器械）', '睡眠仪(器械）', '助行器（器械）', '智能健康（器械）', '微针',
        '微晶类产品', '血压计', '医用健康秤（器械）', '健康监测', '听诊器', '体温计类', '检测试纸', '医用护目镜',
        '医用手套（器械）', '医用眼罩', '耳塞（器械）', '暖贴', '防护服（器械）', '医用口罩（器械）', '医用护理包', '家庭护理',
        '医用胶带', '鼻喷剂', '鼻炎凝胶（器械）', '牙贴（器械）', '医用洗鼻器', '医用应急创伤包', '纱布绷带（器械）',
        '退热贴', '冰袋（器械）', '医用棉签棉球棉片（器械）', '创口贴', '艾灸器', '拔罐器', '体外检测', '医疗器械',
        '智能按钮', '智能家庭设备配件', '家居系统套装', '智能闹钟', '智能灯带', '智能灯光', '智能灯泡', '智能吸顶灯',
        '智能照明配件', '智能射灯', '智能台灯', '智能轨道灯', '中控屏', '智能网关', '全屋智能网关', '万能遥控器',
        '智能可视门铃', '智能安防', '智能摄像头', '智能猫眼', '智能排插', '其他智能家居用品', '用品', 'IT服务',
        '工艺礼品', '毛球修剪器', '其它厨房', '蒸箱', '取暖电器', '电器配件', '电烧烤炉', '收录', '音机', '除湿机',
        '其它大家电', '回收寄卖（请勿上线）', '其他艺术品', '艺术品', '母婴用品', '其他闲置', '其他交通工具', '汽摩',
        '生鲜水果', '图书', '个护美妆', '园艺植物', '五金工具', '电影票', '生活服务', '票务', '卡券', '电子零件',
        '柜子', '其他家具', '回收', '寄卖', '委托服务', '家装', '建材', '实体卡', '票等（非演艺类）', '临期食品',
        '游戏币', '租号', '演艺', '表演类门票', '保险柜', '传真设备', '扫描设备', '投影仪', '多功能一体机', '复合机',
        '装订', '封装机', '点钞机', '台式机', '卡带', '游戏设备', '游戏机', '游戏音频设备', '游戏耳机', '三脚架',
        '镜头', '影棚器材', '小家电', '文体音像', 'CD', 'CD播放器', '高清', '回音壁', '唱片机', '其它影音电器',
        '影音电器配件', '户外音箱', '网络机顶盒', '网络存储', '3G设备', '网络配件', '电脑配件', '鼠标', 'SSD固态硬盘',
        '硬盘', '装机配件', '笔记本配件', '手机整机', '组装电脑', '拍照配件', '数码3C配件', '充电器', '其它数码3C产品',
        'VR眼镜', '其他配饰', '女士鞋靴', '珠宝首饰', '摆饰', '男士鞋靴', '女士服装', '养护服务', '鉴定', '置换服务',
        '质检服务', '其它服务', '养护配件', '瑞士名表', '智能腕表', '手表配件', '男士服装', '潮鞋', '潮服', '潮品配饰',
        '潮玩艺术', '信时空充值卡', '中国移动充值卡', '特惠充值', '鹏博士充值卡', '电信话费充值卡', '爱施德充值卡',
        '免商店充值卡', '天音通信充值卡', '全网通', '三网通 ', '中国联通充值卡', '优酷移动充值卡', '国际通信设备',
        '国际卡', '会员业务', '数据增值业务', '运营商增值业务', '有线宽带办理', '有线宽带', '宽带加速', '中国电信',
        '3G无线上网资费卡', '中国联通', '流量周期包', '增值业务办理续费', '中国移动', '固定电话充值', '有线宽带充值',
        '4G无线上网资费卡', '中国电信china telecom', 'WIFI热点', '无线套餐续费', '中国移动china mobile',
        '中国联通china unicom', '虚拟运营商新号码套餐', '新入网手机号套餐', '中国移动新号码套餐', '中国联通新号码套餐',
        '中国电信新号码套餐', '广电充值', '手机流量充值', '充值送', '虚拟运营商新号码定制套餐', '新入网手机号定制套餐',
        '中国电信新号码定制套餐', '中国联通新号码定制套餐', '中国移动新号码定制套餐', '社交交友', 'APP STORE充值卡',
        '苹果卡', 'App Store直充', 'iTunes卡', '官方电子加油券', '加油服务', '知识阅读', '其他会员充值', '账号充值',
        '平台币', '新能源汽车充电', '充电服务', '移动电源充电', '音频FM', '出行卡券', '出行服务', '网约车充值', '缴费',
        '民生服务', 'X-新侠义道', 'Z-征途点卡', 'T-突击英雄', 'T-天子剑', 'X-新战国', 'Y-约瑟传说', 'S-神魔大陆',
        'F-封神榜3', 'G-GT劲舞团2点卡', 'Y-游戏蜗牛', 'B-霸王点卡', 'S-神雕侠侣点卡', 'S-蜀山剑侠传点卡', 'E-EVE点卡',
        'L-浪漫庄园点卡', '激活码', '新手包', 'Z-装甲战争', '畅秀阁', 'P-派派', 'Q-蜻蜓FM', 'M-陌陌币', 'D-斗鱼',
        'M-喵播喵币', 'J-9158币', 'Y-映客钻石', 'H-花椒豆', 'T-TT语音', 'X-喜马拉雅FM', 'L-荔枝FM金币', 'M-美拍美币',
        'W-玩吧', 'K-快币', 'B-抱抱钻石', 'H-hello语音钻石', 'Y-倚天剑与屠龙刀', 'M-摩尔庄园', 'Z-征途2S点卡',
        'D-地下城与勇士点卡', 'D-大话西游2点卡', 'W-王者之剑', 'D-大三国志', 'Z-中国游戏中心点卡', 'M-魔域点卡',
        'P-泡泡游戏', 'B-飚车点卡', 'T-天谕', 'Z-战意', 'D-大航海时代点卡', 'M-魔域掉钱版', 'D-大唐豪侠点卡',
        'J-骏网充值卡', 'C-创想兵团', 'G-光荣使命', 'M-魔界2点卡', 'T-天之禁', 'X-新英雄年代点卡', 'X-小花仙',
        'R-热血江湖点卡', 'Z-诛仙3', 'J-惊天动地点卡', 'Q-起凡通宝卡', 'Z-镇魔曲', 'H-幻想神域', 'W-巫师之怒点卡',
        'S-圣斗士星矢', 'S-水浒Q传2', 'T-天堂2点卡', 'T-天道', 'W-王者传奇', 'F-FIFA', 'M-魔力宝贝点卡', 'P-泡泡战士',
        'Y-御龙在天', 'Z-战舰世界', 'L-流星蝴蝶剑OL', 'A-暗黑复仇者', 'T-腾讯绿色征途点卡', 'X-仙剑OL点卡',
        'W-武林外传点卡', 'T-淘米一卡通', 'Y-英魂之刃', 'S-圣王', 'F-FIFA Online3', 'M-冒泡一卡通', 'T-天龙八部',
        'Y-远征Online', 'X-（蓝港）西游记点卡', 'J-剑侠情缘网络版3点卡', 'L-炉石传说', 'C-穿越火线点卡', 'M-梦三国点卡',
        'T-天下叁点卡', 'Q-QQ仙灵', 'M-猫扑一卡通', 'M-梦幻诛仙2', 'J-剑侠情缘网络版点卡', 'C-穿越OL点卡',
        'L-绿色版天龙八部', 'B-百度网盘', 'S-三国争霸点卡', 'X-寻仙点卡', '影音阅读', 'J-疾风之刃', 'K-抗战英雄传点卡',
        'S-兽人必须死', 'G-古域点卡', 'S-三国杀Online', 'F-封神榜点卡', 'X-星际争霸2', 'B-百度币', 'Q-QQ仙侠传',
        'R-热血篮球', 'X-降龙之剑点卡', 'J-剑侠贰外传', '网游充值平台（平台加款卡）', 'D-大话水浒点卡', 'D-刀剑英雄点卡',
        'S-神兵传奇点卡', 'C-超级舞者点卡', 'Q-奇虎360币', 'C-传奇3', 'R-热血传奇点卡', 'Q-起点读书', 'Q-奇迹世界2点卡',
        'Q-QQ封神记', 'J-剑侠情缘2点卡', 'P-皮卡堂', 'D-大掌门', 'C-赤壁之战', 'J-劲舞团3', 'X-炫舞吧Ⅱ点卡', 'Q-枪神纪',
        'C-成吉思汗2点卡', 'C-CGA浩方点卡', 'W-网易全明星', 'J-江湖', 'F-风暴战区点卡', 'J-街头篮球点卡',
        'Z-征途时间版点卡', 'D-大话西游3点卡', 'S-三国战魂点卡', 'J-巨人点卡', 'S-守护之剑', 'X-仙途点卡',
        'J-极品飞车OL', 'D-刀锋铁骑', '115网盘', 'D-大唐无双点卡', 'L-洛奇英雄传点卡', 'P-破天一剑点卡', 'U-UC点卡',
        'P-泡泡堂点卡', 'Q-亲朋游戏', 'F-反恐行动', 'J-机动战士敢达OL点卡', 'A-艾尔之光', '其它虚拟充值', 'J-剑灵',
        'X-侠客列传点卡', 'Q-QQ三国点卡', 'Y-影武者', 'F-风暴英雄', 'T-坦克世界点卡', 'J-剑侠世界点卡', 'X-藏地传奇',
        'Y-佣兵天下', 'G-鬼谷无双', 'C-彩虹岛', 'C-传世群英传点卡', 'H-黄金国度', 'C-超能战联', 'F-反恐精英OL点卡',
        'N-逆水寒', 'F-封印者', 'D-斗战神', 'L-黎明之光', 'Y-永恒之塔点卡', 'W-完美点券', 'Z-最后一炮', 'Z-征服点卡',
        'S-丝路传说点卡', 'J-君王2', 'F-封神榜国际版', 'B-波克城市', 'W-无限法则', 'C-冲锋岛点卡', 'C-超级跑跑',
        'L-龙点卡', 'J-九鼎传说', 'X-星辰变', 'Q-倩女幽魂', 'S-蜀山缥缈录', 'Z-纵游充值卡', 'M-梦三国2', 'S-神话',
        'L-零世界', 'L-亮剑', 'M-名将三国点卡', 'Z-最终幻想14（盛大版）', 'T-天天连萌', 'D-夺宝联盟', 'Y-易玩通',
        'Y-优酷土豆', 'F-樊登读书会', 'B-百度文库', 'L-乐视会员', 'Q-QQ阅读', '1-1905电影网', 'M-买虚送实专区',
        'N-南瓜电影', 'B-百合网会员', 'S-世纪佳缘点卡', 'M-陌陌会员', 'K-酷我', 'X-迅雷专区', 'W-WPS专区',
        'X-新浪微博会员', 'Q-全民K歌', 'A-爱奇艺', 'C-CIBN高清影视会员', 'C-苍穹之剑', 'Y-月影传说', 'M-魔兽世界点卡',
        'J-机战', 'S-赛尔号', 'C-赤壁点卡', 'T-天骄2点卡', 'Q-奇迹点卡', 'T-天涯明月刀', 'T-天翼决', 'X-新飞飞点卡',
        'Q-QQ飞车点卡', 'Z-中华英雄', 'Z-真三国无双OL点卡', 'S-三国来了', 'L-鹿鼎记', 'D-豆客CS平台', 'X-新征途',
        'X-炫舞时代', '游戏充值', 'B-不败传说', 'J-街机三国', 'W-武魂', 'Q-千年3点卡', 'J-激战2', 'Z-自由篮球',
        'R-热血战队', 'S-300英雄', 'W-问道点卡', 'V-VS竞技平台VIP', '点卡', 'Q-QQ西游点卡', 'C-传奇归来点卡',
        'S-SD敢达online点卡', 'K-口袋西游点卡', 'D-大话西游之战歌点卡', 'L-绿色征途点卡', 'M-麻辣江湖点卡',
        'Q-QQ自由幻想点卡', 'R-人人一卡通', 'B-边锋点卡', 'Z-斩魂', 'L-雷神加速器', 'M-秘境对决', 'G-功夫派',
        'Q-七雄争霸点卡', 'D-滴滴出行', 'B-霸域', 'X-星际Ⅱ《自由之翼》畅玩版', 'C-传奇世界点卡', 'C-传世无双',
        'X-新水浒Q传', 'Z-征途2经典版点卡', 'Q-全球使命', 'W-万王之王3', 'R-热斗传说点卡', 'Z-醉逍遥',
        'S-三国群英传点卡', 'S-新蜀门点卡', 'F-风云点卡', 'A-奥比岛', 'Y-英雄联盟点卡', 'M-冒险岛点卡',
        'N-诺亚传说点卡', 'C-传奇外传点卡', 'P-啪啪三国', 'R-热舞派对II点卡', 'L-龙之谷点卡', 'T-天宏充值卡',
        'C-春秋Q传点卡', 'X-轩辕传奇', '其他游戏点卡', 'W-完美世界国际版点卡', 'J-九阴真经点卡', 'QQ及网游点卡',
        'Q-全球使命3', 'Q-麒麟点卡', 'C-宠物王国点卡', 'Q-拳皇14-PS4', 'Y-倚天屠龙记', 'Q-群雄逐鹿点卡', 'F-凡人修仙传',
        'H-画皮世界点卡', 'D-DOTA2', 'X-仙剑奇侠传3D回合', '手游充值', 'N-女神联盟', 'F-放开那三国2', '皮皮四川麻将',
        'W-王者荣耀IOS', 'P-皮皮斗地主', 'Q-奇迹暖暖', 'B-捕鱼来了手游', 'S-三国战纪', 'H-欢乐麻将全集', 'D-大唐麻将',
        'F-放开那三国', 'H-航海王强者之路', '首充号充值', 'X-闲来游戏', 'H-豪门足球风云', 'D-刀塔传奇', 'Q-其它',
        'A-安卓平台币-oppo', '星悦福建麻将', 'S-少年三国志', 'S-新神曲', 'H-胡莱三国2', 'M-魔域口袋版', 'Z-中超风云',
        'T-天龙八部手游', 'H-火影忍者-忍者大师', 'S-赛博加速器', 'L-烈焰飞雪', 'J-劲舞团点卡', 'W-舞街区点卡', 'N-逆战',
        'X-星尘传说点卡', 'X-仙侠世界点卡', 'S-兽血沸腾点卡', 'L-洛奇点卡', 'B-霸王II', 'M-米币', 'w-豌豆币',
        'M-冒险岛2', 'X-新热血英豪', 'J-剑侠世界绿色版', 'P-拍拍部落', 'B-暴雪游戏一卡通', 'S-三国策点卡', 'S-32充值卡',
        'Y-英雄三国', 'Q-QQ华夏点卡', 'X-笑傲江湖', 'Q-QQ幻想点卡', 'Y-一起来飞车', '网页游戏点卡', 'W-完美世界点卡',
        'N-NBA2K', 'S-神鬼传奇点卡', 'M-梦想世界点卡', 'T-桃园', 'Z-征途怀旧版点卡', 'M-梦幻西游点卡',
        'D- 夺宝传世点卡', 'R-热血英豪', 'D-斗破苍穹', 'W-网易严选', 'T-泰亚史诗', 'S-守望先锋', 'D-大海战II点卡',
        'S-盛趣点券', 'Y-11对战平台', 'L-龙武', 'X-西楚霸王', 'W-武神点卡', 'S-神鬼世界', 'A-暗黑破坏神3',
        'P-跑跑卡丁车点卡', 'X-侠义道II点卡', 'X-星际战甲', 'B-百万亚瑟王', 'H-黄金岛点卡', 'H-虎豹骑', 'C-传奇永恒',
        'J-精灵传说点卡', 'M-魔法哈奇', '游戏帐号租赁', 'W-新武林外传帐号', '游戏帐号', '游戏装备', '激活码测试号专区',
        '游戏队友', '网页游戏物品', '资源', '健康保险', '意外保险', '财产保险', '年金保险', '人寿保险', '外卖卡券',
        '餐饮美食卡券', '其他美食折扣券', '烧肉', '烤鱼', '自助餐', '干锅', '豆捞', '茶楼', '茶馆', '羽毛球馆',
        '滑雪场', '儿童游泳', '其他休闲娱乐', '休闲娱乐', '洗衣机清洗', '家政服务', '油烟机清洗', '空调清洗',
        '物业保洁', '灯具清洗', '空气净化', '高空清洗', '除虫除蚁', '门窗清洗', '石材翻新', '沙发保养清洗', '壁纸清洗',
        '玻璃清洗', '其他类型', '地板保养', '管道疏通', '房屋维修', '电路安装', '墙面粉刷', '补裂', '防水补漏',
        '马桶疏通', '房屋翻新', '水管安装', '灶具维修', '暖气安装', '门窗维修', '打孔', '化粪池处理', '开锁', '修锁',
        '换锁', '亲子游玩', '亲子游泳', '报刊杂志订阅', '便民服务', '生活服务优惠券', '起名服务', '理财咨询', '水电煤',
        '生活缴费', '改衣', '蔬果配送', '其他社区服务', '其他配送服务', '配镜服务', '修伞', '修表', '修鞋', '空调维修',
        '家电相关服务', '其他家电维修', '电器延保', '增值服务', '电磁炉维修', '功放维修', '服饰搭配', '特色服务',
        '教练陪练', '上门美容按摩服务', '其他特色服务', '告示牌', '指示牌', '广告制作', '传统印刷', '打印', '复印',
        '广告语设计', '喷绘', '推广文案撰写', '广告位招租', '打印服务', '条幅', '横幅', '活动策划', '信息发布',
        '复印服务', '其他广告营销服务', '灯箱', '美容美发', '美体美甲', '纤体', '其他美业服务', '综合卡', '服务卡',
        '法律咨询', '法律服务', '合同文书', '生活配送', '家居物流', '配送', '家居配送', '其他家居服务', '装修施工',
        '家居装修施工', 'KTV包厢预定', 'KTV包厢券（非预订）', 'KTV包厢+酒水', '进出口代理', '商务服务', '会计服务',
        '设备维修或租赁服务', '其他商务服务', '迁厂搬家', '市场调研', '安全保卫', '硒鼓加粉服务', '物业管理',
        '工商注册', '知识产权', '专利申请', '汽车检测检查', '车况评估服务', '汽车服务卡', '其他数码产品维修',
        '3C数码服务', '手机维修', '台式电脑', '数据恢复', '相机维修', '笔记本维修', '数码维修服务', '国内代购', '代购',
        '本地婚纱摄影', '婚庆', '摄像服务', '婚宴酒店', '婚礼策划', '婚礼跟拍', '婚礼化妆', '跟妆', '旅游婚纱摄影',
        '婚礼表演', '婚礼司仪', '婚礼摄影', '汽车用品清洗', '在线清洗', '洗衣券', '在线洗衣', '家居用品清洗',
        '窗帘清洗', '地毯清洗', '家政服务卡', '皮革清洗养护', '鞋类清洗', '女装兑换卡', '垂钓运动兑换卡', '家电服务卡',
        '本地化生活服务卡', '服饰清洗卡', '烘焙原料兑换卡', '米面杂粮兑换卡', '方便速食兑换卡', '沙拉兑换卡',
        '调味油兑换卡', '冲饮兑换卡', '成人奶粉兑换卡', '天然粉粉食品兑换卡', '食补粉粉兑换卡', '图书音像兑换卡',
        '男鞋卡', '食品及用品卡', '婴儿用品卡', '啤酒兑换卡', '酒类卡', '国产白酒兑换卡', '葡萄酒兑换卡', '黄酒兑换卡',
        '配制酒', '果酒兑换卡', '洋酒兑换卡', '尿裤卡', '女鞋卡', '男士内衣', '家居服卡', '护理液兑换卡', '饮料兑换卡',
        '南北干货兑换卡', '水产肉类', '新鲜蔬果', '熟食卡', '脱水蔬菜卡', '半成品菜兑换卡', '水果制品兑换卡',
        '制品兑换卡', '新鲜水果兑换卡', '蛋制品兑换卡', '新鲜蔬菜', '蔬菜制品兑换卡', '肉制品兑换卡', '辅食卡',
        '医学美容卡', '医美医疗卡', '商业设备卡', '膳食营养补充食品卡', '枣蜜饯兑换卡', '零食类兑换卡', '巧克力兑换卡',
        '糖果兑换卡', '饼干膨化兑换卡', '豆干兑换卡', '新鲜蛋糕兑换卡', '糕点兑换卡', '坚果兑换卡', '肉干卤味兑换卡',
        '文具电教文化用品兑换卡', '护理剂卡', '皮具护理品卡', '湿巾卡', '家庭环境清洁剂卡', '孕产用品卡', '精油卡',
        '传统滋补营养品卡', '生活电器兑换卡', '童装卡', '冰淇淋卡', '医疗器械兑换卡', '童鞋卡', '3C数码配件兑换卡',
        '美容美体仪器卡', '鲜花园艺卡', '男装兑换卡', '运动户外卡', '餐饮具卡', '百货兑换卡', '甜品', '咖啡兑换卡',
        '餐饮美食兑换卡', '玩具卡', '美妆工具卡', '私处护理卡', '个护卡', '身体护理卡', '身体清洁卡', '口腔护理卡',
        '其他个护卡', '美护发卡', '地板清洁用具卡', '个人清洁工具卡', '个人洗护清洁用具卡', '特产卡', '食品类',
        '奶酪兑换卡', '茶类兑换卡', '粉类兑换卡', '服饰配件兑换卡', '乳制品兑换卡', '其他饮品兑换卡', '提货卡',
        '食品卡', '综合通用卡', '便民店卡', '超市商场', '购物消费卡', '付费会员卡', '付费会员', '商场', '百货购物卡',
        '智能学习', '学习平台', '学业规划', '职业规划师', '人力资源师认证', '学历', '职业资格考试', '自学考试培训',
        '医学类资格认证', '远程网络教育培训', 'IT资格认证', '建筑地产类培训', '银行', '证券培训', '教师资格培训',
        '会计培训', '公务员培训', '健康管理师培训', '其他职业资格认证培训', '研究生考试', '公务员', '事业单位培训',
        '本地教育培训', '职业考试线下培训', '家长课堂', '亲子营', '个人修养', '成人语言线下培训', '少儿英语门店',
        '研学', '游学营', '电商培训', 'K12线下教育', '早教中心门店', '自学考试', '升学考试', '少儿才艺门店', '汽修',
        '成人职业资格考试', '常识兴趣', '健康养生', '通识趣味', '个人形象', '医疗科普', '棋类', '数独', '其他兴趣',
        '摄影摄像', '神秘学', '美术', '主持表演', '思维感统', '学习卡', '实习就业', '海外学业辅导', '游学', '留学申请',
        '背景提升', '语言培训', '语言师资培训', '德语', '其他语种', '日语', '数字化语言学习', '葡萄牙语', '启蒙早教',
        '儿童兴趣', '中小幼师资培训', '学前教育', '家长教育', '高考志愿填报', '高中辅导', '笔译服务', '教学服务',
        '宣传文案', '文章写作', 'office办公制作', '方案策划', '考试题库软件', '口译服务', '论文检测与查询',
        '家政服务类培训', '家政家居', '心理咨询培训', '设计·创作', '烹饪烘焙小吃餐饮培训', '建工电气', '经济学',
        '金融学知识', '项目管理培训', '经济师培训', '办公软件&效率软件', '电脑基础', '知识付费', 'IT职业', '编程',
        '计算机考试', '互联网产品运营', '电商运营', '企业人力资源', '市场营销', '职业规划', '速冻', '冷冻食品券',
        '食品提货券', '水产提货券', '干货炒货提货券', '水果提货券', '酒水', '饮用水券', '其他食品提货券', '粽子提货券',
        '年夜饭', '熟食', '半成品券', '禽蛋提货券', '粮油米面提货券', '西点', '珠宝饰品', '购物券', '礼品卡',
        '年货购物礼品卡', '鲜花', '礼品', '服饰鞋包', '超市优惠券', '其它购物券', '母婴儿童', '办公', '文化用品',
        '数码家电', '家具家居', '营养保健品', '健康医疗', '化妆品', '书城', '冷饮', '美食代金券', '其他类 ',
        '体育赛事 ', '田径类 ', '电竞类 ', '赛事周边', '球类 ', '综合赛事 ', '电影卡券', ' 电影选座', '电影周边',
        '演唱会', '小型现场 ', '演出周边', '儿童亲子', '曲艺杂技 ', '话剧歌剧', '活动周边', '休闲活动 ', '展览展会 ',
        '优惠券', '新房', '核酸检测', '基因检测', '洗牙洁牙', '口腔齿科', '新冠疫苗', '疫苗服务', '公立体检',
        '健康体检', '私立体检', '其他奢品', '奢品家纺', '奢品家居', '奢品餐具', '奢品家具', '其他奢品家居',
        '奢品书写工具', '奢品lifestyle家居摆件', '装饰', '奢品书籍', '户外登山徒步越野服饰', '马术服饰',
        '户外自行车服饰', '网球服饰', '瑜伽配件', '户外登山徒步越野配件', '高尔夫服饰', '滑雪服饰', '高尔夫配件',
        '户外其他', '户外垂钓配件', '网球配件', '滑雪配件', '户外自行车配件', '轮滑配件', '搏击配件', '游泳服饰',
        '冲浪潜水配件', '马术配件', '户外垂钓服饰', '瑜伽服饰', '训练配件', '游泳配件', '轮滑服饰', '冲浪潜水服饰',
        '训练服饰', '搏击服饰', '服饰鞋靴', '盲盒', '奢品护肤', '奢品美妆', '奢品彩妆', '奢品腕表配件', '奢品钟表',
        '其他奢品钟表', '奢品电子腕表', '奢品石英腕表', '奢品机械腕表', '奢品怀表', '奢品古董', '典藏表',
        '奢品高级珠宝腕表', '奢品礼盒礼赠', '奢品香水', '奢品香薰', '奢品身体护理', '奢品袖扣', '奢品珠宝', '奢品手链',
        '奢品项链', '坠饰', '奢品手绳', '奢品耳环', '奢品胸针', '奢品戒指', '其他奢品珠宝配饰', '奢品内裤', '奢品服饰',
        '奢品羽绒服', '奢品皮草', '奢品婚纱', '奢品连体衣', '其他奢品服饰', '奢品连衣裙', '奢品打底裤', '奢品睡衣',
        '奢品半身裙', '奢品丝袜', '奢品皮裤', '奢品风衣', '奢品袜子', '奢品休闲裤', '奢品羊毛衫', '奢品抹胸',
        '奢品针织衫', '奢品西装', '奢品牛仔裤', '奢品棉衣', '奢品西裤', '奢品毛衣', '奢品保暖内衣', '奢品卫衣',
        '奢品马甲', '奢品文胸套装', '奢品短裤', '奢品夹克', '奢品塑身衣', '奢品内衣配件', '奢品T恤', '奢品蕾丝衫',
        '奢品衬衫', '奢品文胸', '奢品棉裤', '奢品西装套装', '奢品皮衣', '奢品短外套', '奢品Polo衫', '奢品大衣',
        '奢品羽绒裤', '奢品卫裤', '奢品背心吊带', '奢品鞋靴', '奢品芭蕾舞鞋', '奢品孟克鞋', '奢品高跟鞋', '奢品凉鞋',
        '奢品乐福鞋', '奢品拖鞋', '训练鞋', '奢品人字拖', '奢品草编鞋', '其他奢品鞋靴', '奢品穆勒鞋', '奢品德比鞋',
        '奢品靴子', '奢品牛津鞋', '其他奢品平底鞋', '奢品布洛克鞋', '奢品运动鞋', '奢品迷你包袋', '奢品箱包',
        '奢品腰包', '奢品行李箱', '奢品包袋配饰', '奢品户外摄影包', '奢品单肩包', '奢品水桶包', '奢品箱包相关配件',
        '奢品典藏包袋', '奢品旅行包袋', '奢品斜挎包', '奢品双肩包', '奢品手拿包', '奢品收纳配件包', '奢品电脑包',
        '公文包', '奢品手提包', '奢品邮差包', '其他奢品箱包', '奢品太阳眼镜', '奢品配饰', '奢品眼镜和镜框', '奢品腰带',
        '奢品雨伞', '奢品手套', '奢品首饰收纳', '奢品化妆包', '奢品钥匙扣和钥匙链', '其他奢品配饰', '奢品发饰',
        '奢品数码产品及配件', '奢品装饰假领', '奢品领带和领结', '奢品口罩', '奢品钱包和卡夹', '奢品帽子', '奢品围巾',
        '奢品旅行用品', '汽配安装', '售后服务', '新车优惠券', '新车一口价', '二手车抵扣券', '二手车订金']
